@@ -1,7 +1,8 @@
 #!/usr/bin/env python3
-"""Direct Pulumi + Flow SDK integration."""
+"""Direct Pulumi + Flow integration."""
 
 import pulumi
+
 import flow
 
 # GPU instance
