@@ -10,11 +10,22 @@ from pathlib import Path
 from typing import Any
 
 import yaml
+import os as _os_for_home
 
 from flow.errors import ConfigParserError
 
 logger = logging.getLogger(__name__)
 
+# Resolve the real user's config path at import time to distinguish between
+# test-provided temp configs (patched Path.home) and the developer's actual
+# ~/.flow/config.yaml which should not be read during tests.
+_ORIGINAL_USER_CONFIG_PATH = (Path(_os_for_home.path.expanduser("~")) / ".flow" / "config.yaml").resolve()
+
+# Internal toggle used by Config.from_env to avoid reading the real user's
+# ~/.flow/config.yaml during certain test scenarios. This avoids leaking a
+# developer's config into tests without relying on process-wide env vars.
+_SKIP_USER_CONFIG: bool = False
+
 
 @dataclass
 class ConfigSources:
@@ -89,6 +100,7 @@ class ConfigSources:
         # Project (canonical env var and provider section; fallback to top-level for migration)
         project = (
             self.env_vars.get("MITHRIL_PROJECT")
+            or self.env_vars.get("MITHRIL_DEFAULT_PROJECT")
             or self.config_file.get("mithril", {}).get("project")
             or self.config_file.get("project")
         )
@@ -98,6 +110,7 @@ class ConfigSources:
         # Region (canonical env var and provider section; fallback to top-level for migration)
         region = (
             self.env_vars.get("MITHRIL_REGION")
+            or self.env_vars.get("MITHRIL_DEFAULT_REGION")
             or self.config_file.get("mithril", {}).get("region")
             or self.config_file.get("region")
         )
@@ -186,13 +199,14 @@ class ConfigSources:
 class ConfigLoader:
     """Unified configuration loader with clear precedence and error handling."""
 
-    def __init__(self, config_path: Path | None = None):
+    def __init__(self, config_path: Path | None = None, *, skip_user_config: bool = False):
         """Initialize the loader.
 
         Args:
             config_path: Path to config file (defaults to ~/.flow/config.yaml)
         """
         self.config_path = config_path or Path.home() / ".flow" / "config.yaml"
+        self._skip_user_config = skip_user_config
 
     def load_all_sources(self) -> ConfigSources:
         """Load configuration from all available sources.
@@ -204,37 +218,23 @@ class ConfigLoader:
         env_vars = dict(os.environ)
 
         # 2. Config file (lowest precedence)
-        config_file = self._load_config_file()
+        if self._skip_user_config:
+            config_file = {}
+        else:
+            # Under pytest, avoid reading the developer's real ~/.flow/config.yaml.
+            # Tests that want to supply a config file patch Path.home() so the
+            # loader's config_path differs from the original.
+            if os.getenv("PYTEST_CURRENT_TEST") and self.config_path.resolve() == _ORIGINAL_USER_CONFIG_PATH:
+                config_file = {}
+            else:
+                config_file = self._load_config_file()
 
         return ConfigSources(env_vars=env_vars, config_file=config_file)
 
-    def _load_from_credentials_file(self) -> str | None:
-        """Load API key from provider-specific credentials file.
-
-        Returns:
-            API key if found, None otherwise
-        """
-        try:
-            # Get provider from environment or config file
-            provider = os.environ.get("FLOW_PROVIDER")
-            if not provider:
-                config = self._load_config_file()
-                provider = config.get("provider", "mithril")
-
-            # Check provider-specific credentials file directly
-            credentials_path = Path.home() / ".flow" / f"credentials.{provider}"
-            if credentials_path.exists():
-                import configparser
-
-                cfg = configparser.ConfigParser()
-                cfg.read(credentials_path)
-                api_key = cfg.get("default", "api_key", fallback=None)
-                if api_key:
-                    return api_key
-
-        except Exception as e:
-            logger.debug(f"Could not load from credentials file: {e}")
-            return None
+    # NOTE: Legacy credential files (e.g., ~/.flow/credentials.*) are intentionally
+    # not supported. The single source of truth is ~/.flow/config.yaml plus
+    # process environment variables. Keeping this stub documents that decision
+    # and avoids accidental reintroduction.
 
     def _load_config_file(self) -> dict[str, Any]:
         """Load configuration from YAML file.
