@@ -7,12 +7,16 @@ import yaml
 
 
 class ConfigResolver:
-    """Resolves configuration from multiple sources with clear precedence."""
+    """Deprecated helper for early init flows.
+
+    This resolver is not used by the current configuration system. The
+    single source of truth is `ConfigLoader` + `ConfigManager`.
+    """
 
     DEFAULTS = {
         "api_key": None,
         "project": None,
-        "region": "us-central1-a",
+        "region": "us-central1-b",
         "api_url": "https://api.mithril.ai",
     }
 
@@ -20,13 +24,17 @@ class ConfigResolver:
         self.config_path = config_path or Path.home() / ".flow" / "config.yaml"
 
     def resolve(self, cli_args: dict[str, Any], env: dict[str, str]) -> dict[str, Any]:
-        """Resolve configuration: CLI > Environment > File > Defaults."""
-        return {
-            **self.DEFAULTS,
-            **self._load_file_config(),
-            **self._load_env_config(env),
-            **{k: v for k, v in cli_args.items() if v is not None},
-        }
+        """Resolve configuration: CLI > Environment > File > Defaults (legacy)."""
+        merged = dict(self.DEFAULTS)
+        # File (lowest of the three explicit sources)
+        file_cfg = self._load_file_config()
+        merged.update({k: v for k, v in file_cfg.items() if v is not None})
+        # Env overrides file
+        env_cfg = self._load_env_config(env)
+        merged.update({k: v for k, v in env_cfg.items() if v is not None})
+        # CLI overrides env
+        merged.update({k: v for k, v in cli_args.items() if v is not None})
+        return merged
 
     def _load_file_config(self) -> dict[str, Any]:
         """Load configuration from file."""
@@ -57,18 +65,25 @@ class ConfigResolver:
         return config
 
     def _load_env_config(self, env: dict[str, str]) -> dict[str, Any]:
-        """Load configuration from environment variables."""
+        """Load configuration from environment variables (legacy aliases included)."""
         config = {}
 
         # Provider-specific API key
-        if "MITHRIL_API_KEY" in env or "Mithril_API_KEY" in env:
-            config["api_key"] = env.get("MITHRIL_API_KEY") or env.get("Mithril_API_KEY")
-        if "MITHRIL_PROJECT" in env or "Mithril_PROJECT" in env:
-            config["project"] = env.get("MITHRIL_PROJECT") or env.get("Mithril_PROJECT")
-        if "MITHRIL_REGION" in env or "Mithril_REGION" in env:
-            config["region"] = env.get("MITHRIL_REGION") or env.get("Mithril_REGION")
-        if "MITHRIL_API_URL" in env or "Mithril_API_URL" in env:
-            config["api_url"] = env.get("MITHRIL_API_URL") or env.get("Mithril_API_URL")
+        # Canonical vars first
+        if "MITHRIL_API_KEY" in env:
+            config["api_key"] = env.get("MITHRIL_API_KEY")
+        if "MITHRIL_PROJECT" in env:
+            config["project"] = env.get("MITHRIL_PROJECT")
+        if "MITHRIL_REGION" in env:
+            config["region"] = env.get("MITHRIL_REGION")
+        if "MITHRIL_API_URL" in env:
+            config["api_url"] = env.get("MITHRIL_API_URL")
+
+        # Legacy compatibility (soft-deprecated)
+        config.setdefault("api_key", env.get("Mithril_API_KEY"))
+        config.setdefault("project", env.get("Mithril_PROJECT"))
+        config.setdefault("region", env.get("Mithril_REGION"))
+        config.setdefault("api_url", env.get("Mithril_API_URL"))
 
         return config
 
