@@ -139,7 +139,7 @@ class ConfigValidator:
             if response.status_code == 200:
                 data = response.json()
                 return [
-                    Project(name=p["name"], region=p.get("region", "us-central1-a")) for p in data
+                    Project(name=p["name"], region=p.get("region", "us-central1-b")) for p in data
                 ]
         except Exception:
             pass
