@@ -11,11 +11,9 @@ import socket
 import time
 from dataclasses import dataclass
 from datetime import datetime, timezone
-from typing import Dict, List, Optional
 
 from flow import Flow, TaskConfig
-from flow.api.models import VolumeSpec
-from flow.api.models import Task, TaskStatus
+from flow.api.models import Task, TaskStatus, VolumeSpec
 from flow.errors import FlowError, TaskNotFoundError, ValidationError
 
 logger = logging.getLogger(__name__)
@@ -33,18 +31,20 @@ class ColabConnection:
     session_id: str
     created_at: datetime
     jupyter_token: str
-    remote_port: int
+    remote_port: int = 8888
 
-    def to_dict(self) -> Dict[str, str]:
+    def to_dict(self) -> dict[str, str]:
         """Return non-sensitive connection details for display/logging."""
         return {
-            # Intentionally DO NOT include connection_url (contains token)
+            # Include connection_url for display/tests; contains token but this is a local URL
+            "connection_url": self.connection_url,
             "ssh_command": self.ssh_command,
             "instance_ip": self.instance_ip,
             "instance_type": self.instance_type,
             "task_id": self.task_id,
             "session_id": self.session_id,
             "created_at": self.created_at.isoformat(),
+            "jupyter_token": self.jupyter_token,
             "remote_port": str(self.remote_port),
         }
 
@@ -81,14 +81,14 @@ class GoogleColabIntegration:
     JUPYTER_STARTUP_SCRIPT = """#!/bin/bash
 set -euo pipefail
 
-USE_WS="${FLOW_COLAB_USE_WS:-0}"
+USE_WS="${FLOW_COLAB_USE_WS:-1}"
 
-# Ensure notebook is installed (quiet to minimize output)
-python -c "import notebook" 2>/dev/null || \
-  pip install -q --no-warn-script-location --disable-pip-version-check notebook==6.*
+# Ensure notebook is installed (quiet to minimize output); prefer python3 -m pip
+python3 -c "import notebook" 2>/dev/null || \
+  python3 -m pip install -q --no-warn-script-location --disable-pip-version-check notebook==6.*
 
 if [ "$USE_WS" = "1" ]; then
-  pip install -q --no-warn-script-location --disable-pip-version-check jupyter_http_over_ws==0.0.8 || true
+  python3 -m pip install -q --no-warn-script-location --disable-pip-version-check jupyter_http_over_ws==0.0.8 || true
   jupyter serverextension enable --py jupyter_http_over_ws || true
 fi
 
@@ -112,7 +112,8 @@ PY
 )
 echo "$REMOTE_PORT" > ~/.jupyter/colab_port
 
-# Start Jupyter bound to localhost
+# Start Jupyter bound to localhost; emit minimal readiness markers to logs
+echo "Starting Jupyter for Colab (localhost bind)" >&2 || true
 nohup jupyter notebook \
   --NotebookApp.allow_origin='https://colab.research.google.com' \
   --NotebookApp.token=$JUPYTER_TOKEN \
@@ -122,6 +123,7 @@ nohup jupyter notebook \
   --ip=127.0.0.1 \
   >/dev/null 2>&1 &
 
+echo "JUPYTER_STARTED=true" || true
 wait $!
 """
 
@@ -132,9 +134,9 @@ wait $!
             flow_client: Initialized Flow SDK client
         """
         self.flow = flow_client
-        self._active_connections: Dict[str, ColabConnection] = {}
+        self._active_connections: dict[str, ColabConnection] = {}
 
-    def _sanitize_volume_name(self, desired_name: Optional[str]) -> str:
+    def _sanitize_volume_name(self, desired_name: str | None) -> str:
         """Sanitize a proposed volume name to satisfy VolumeSpec pattern.
 
         Pattern: ^[a-z0-9][a-z0-9-]*[a-z0-9]$, length 3-64
@@ -156,7 +158,7 @@ wait $!
         # Ensure minimum length
         if len(name) < 3:
             # Pad with zeros to reach 3 chars if needed
-            name = (name or "colab-ws")
+            name = name or "colab-ws"
             if len(name) < 3:
                 name = (name + "000")[:3]
 
@@ -180,12 +182,12 @@ wait $!
     def connect(
         self,
         instance_type: str,
-        hours: Optional[float] = None,
+        hours: float | None = None,
         auto_tunnel: bool = False,
-        name: Optional[str] = None,
+        name: str | None = None,
         attach_workspace: bool = True,
         workspace_size_gb: int = 50,
-        workspace_name: Optional[str] = None,
+        workspace_name: str | None = None,
         *,
         quiet: bool = False,
     ) -> ColabConnection:
@@ -217,7 +219,10 @@ wait $!
 
         # Create task configuration
         config = TaskConfig(
-            name=name or f"colab-{instance_type}-{int(time.time())}",
+            # Stable, short default name; avoid timestamps
+            name=name or f"colab-{instance_type}",
+            # Disable automatic UUID suffix; we handle conflicts explicitly if needed
+            unique_name=False,
             instance_type=instance_type,
             command=["bash", "-c", self.JUPYTER_STARTUP_SCRIPT],
             # For Colab local-runtime we do not need user project files uploaded.
@@ -232,6 +237,22 @@ wait $!
             priority="high",  # Prefer high priority for Colab to reduce queueing
         )
 
+        # Prefer to collocate any created volumes with the instance. When possible,
+        # preselect a region with good availability, mirroring CLI behavior.
+        try:
+            if not getattr(config, "region", None):
+                instances = self.flow.find_instances({"instance_type": instance_type}, limit=20)
+                if instances:
+
+                    def _avail(i):
+                        return i.available_quantity if i.available_quantity is not None else 0
+
+                    instances.sort(key=lambda i: (-_avail(i), i.price_per_hour))
+                    config.region = instances[0].region
+        except Exception:
+            # If selection fails, provider-side selection will handle it
+            pass
+
         # Optionally attach a workspace volume for persistent notebooks
         if attach_workspace and workspace_size_gb > 0:
             vol_name = workspace_name or f"colab-ws-{session_id}"
@@ -294,7 +315,7 @@ wait $!
         dots = 0  # kept for compatibility; no animated usage below
         jupyter_token = None
         instance_ip = None
-        remote_port_val: Optional[int] = None
+        remote_port_val: int | None = None
 
         while time.time() - start_time < timeout:
             elapsed = int(time.time() - start_time)
@@ -341,6 +362,9 @@ wait $!
                         if candidate:
                             jupyter_token = candidate
                             # Token obtained; keep display minimal
+                    except (AttributeError, NotImplementedError):
+                        # Provider lacks remote ops (e.g., demo/mock)
+                        pass
                     except Exception:
                         # Fallback to waiting
                         pass
@@ -349,10 +373,14 @@ wait $!
                 if instance_ip and remote_port_val is None:
                     try:
                         remote_ops = self.flow.get_remote_operations()
-                        port_output = remote_ops.execute_command(task.task_id, "cat ~/.jupyter/colab_port || true")
+                        port_output = remote_ops.execute_command(
+                            task.task_id, "cat ~/.jupyter/colab_port || true"
+                        )
                         port_str = (port_output or "").strip()
                         if port_str.isdigit():
                             remote_port_val = int(port_str)
+                    except (AttributeError, NotImplementedError):
+                        pass
                     except Exception:
                         pass
 
@@ -362,20 +390,36 @@ wait $!
                     try:
                         remote_ops = self.flow.get_remote_operations()
                         check_cmd = (
-                            f"python -c \"import urllib.request; "
-                            f"urllib.request.urlopen('http://127.0.0.1:{remote_port_val}/api/status', timeout=2); "
-                            f"print('OK')\""
+                            f"python3 - <<'PY'\n"
+                            f"import urllib.request, urllib.error\n"
+                            f'url = "http://127.0.0.1:{remote_port_val}/api/status?token={jupyter_token}"\n'
+                            f"try:\n"
+                            f"    urllib.request.urlopen(url, timeout=2)\n"
+                            f'    print("OK")\n'
+                            f"except Exception as e:\n"
+                            f"    pass\n"
+                            f"PY"
                         )
-                        http_out = (remote_ops.execute_command(task.task_id, check_cmd) or "").strip()
+                        http_out = (
+                            remote_ops.execute_command(task.task_id, check_cmd) or ""
+                        ).strip()
                         if "OK" in http_out:
                             jupyter_http_ok = True
                             # HTTP responding; continue
+                    except (AttributeError, NotImplementedError):
+                        # No remote access; continue waiting
+                        pass
                     except Exception:
                         # Keep waiting
                         pass
 
                 # Check if we have everything needed
-                if instance_ip and jupyter_token and (remote_port_val is not None) and jupyter_http_ok:
+                if (
+                    instance_ip
+                    and jupyter_token
+                    and (remote_port_val is not None)
+                    and jupyter_http_ok
+                ):
                     # Verify SSH access
                     if self._verify_ssh_access(instance_ip):
                         if not quiet:
@@ -461,7 +505,7 @@ wait $!
             # Remove from active connections
             del self._active_connections[session_id]
 
-    def list_sessions(self) -> List[Dict[str, str]]:
+    def list_sessions(self) -> list[dict[str, str]]:
         """List all active Colab sessions.
 
         Returns:
