@@ -92,11 +92,10 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
                 field_type=FieldType.CHOICE,
                 required=False,
                 choices=[
-                    "us-central1-a",
-                    "us-central1-c",
-                    "us-east1-c",
-                    "us-west1-b",
-                    "europe-west4-a",
+                    "us-central2-a",
+                    "us-central1-b",
+                    "eu-central1-a",
+                    "eu-central1-b",
                 ],
                 default="us-central1-b",
                 help_text="Default region for instances",
@@ -137,7 +136,8 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
             payload = dict(config)
             payload.setdefault("provider", "mithril")
             saved = manager.save(payload)
-            manager.write_env_script(saved)
+            # Write env script without embedding the API key by default
+            manager.write_env_script(saved, include_api_key=False)
             return True
         except Exception:
             return False
