@@ -834,7 +834,21 @@ class Flow:
             raise AttributeError(
                 f"Provider {provider.__class__.__name__} doesn't support SSH key management"
             )
-        return provider.ssh_key_manager
+        # Ensure project scoping is applied so platform APIs that require
+        # project context (e.g., SSH key creation) do not fail with
+        # validation errors like "project: Field is required".
+        manager = provider.ssh_key_manager
+        try:
+            # Only set if not already scoped to avoid unnecessary calls.
+            if getattr(manager, "project_id", None) is None:
+                # Provider exposes a project_id property that resolves lazily.
+                manager.project_id = provider.project_id  # type: ignore[attr-defined]
+        except Exception:
+            # Do not hard-fail here; individual operations will surface errors
+            # with richer context if scoping is still missing.
+            pass
+
+        return manager
 
     def close(self) -> None:
         """Release provider resources (idempotent)."""
