@@ -323,7 +323,7 @@ class DevEnvironment:
 
         # Wait for SSH readiness if needed
         if not vm.ssh_host:
-            from flow.providers.mithril.ssh_utils import wait_for_task_ssh_info
+            from flow.api.ssh_utils import wait_for_task_ssh_info
 
             # Ensure provider is initialized (use public accessor)
             provider = self._flow.provider
