@@ -10,7 +10,13 @@ if TYPE_CHECKING:
 
 
 # Default provisioning timeout expectations
-DEFAULT_PROVISION_MINUTES = 12  # Typical provision time for GPU instances
+# Source from top-level constant if available to keep UX consistent across CLI
+try:
+    from flow import DEFAULT_PROVISION_MINUTES as _FLOW_DEFAULT_PROVISION_MINUTES  # type: ignore
+    DEFAULT_PROVISION_MINUTES = int(_FLOW_DEFAULT_PROVISION_MINUTES)  # e.g., 20
+except Exception:
+    # Fallback for import cycles or partial imports
+    DEFAULT_PROVISION_MINUTES = 20
 
 
 class SSHNotReadyError(Exception):
