@@ -13,6 +13,9 @@ def main():
             f"Recommended: Install and use 'uv' for automatic Python version management:\n"
             f"  curl -LsSf https://astral.sh/uv/install.sh | sh\n"
             f"  uv tool install flow-compute\n\n"
+            f"Or install without uv:\n"
+            f"  pipx install flow-compute\n"
+            f"  # macOS/Linux one-liner: curl -fsSL https://raw.githubusercontent.com/mithrilcompute/flow/main/scripts/install.sh | sh\n\n"
             f"Alternative: Upgrade your Python installation to 3.10 or later.",
             file=sys.stderr,
         )
