@@ -123,7 +123,7 @@ class LazyDYMGroup(OrderedDYMGroup):
     def format_commands(self, ctx: click.Context, formatter: click.HelpFormatter) -> None:
         # Group commands into lifecycle sections without importing heavy modules
         groups: dict[str, list[str]] = {
-            "Getting started": ["tutorial", "init", "demo"],
+            "Getting started": ["tutorial", "init", "docs", "demo"],
             "Run": ["run", "dev", "example", "grab"],
             "Observe": ["status", "logs"],
             "Manage": [
@@ -220,12 +220,6 @@ def print_version(ctx: click.Context, param: click.Option | None, value: bool) -
     default=None,
     help="Enable/disable hyperlinks (default: auto)",
 )
-@click.option(
-    "--demo/--no-demo",
-    envvar="FLOW_DEMO_MODE",
-    default=None,
-    help="Demo mode: simulate runs with a mock provider (no real provisioning).",
-)
 @click.option(
     "--simple/--no-simple",
     envvar="FLOW_SIMPLE_OUTPUT",
@@ -238,20 +232,19 @@ def cli(
     theme: str | None,
     no_color: bool,
     hyperlinks: bool | None,
-    demo: bool | None,
     simple: bool | None,
 ) -> None:
-    """Flow CLI — run and manage GPU workloads.
+    """Flow CLI - Submit and manage GPU tasks.
 
-    The Flow CLI helps you provision GPU instances/clusters, run workloads from YAML or command, and
-    monitor/manage tasks end-to-end.
+    Flow CLI helps you provision GPU instances/clusters, run workloads from YAML or command,
+    and monitor/manage tasks end-to-end.
 
     \b
     Quickstart:
-      1) flow tutorial              # Guided setup
-      2) flow init                  # Configure API key
-      3) flow example gpu-test      # Verify GPU access
-      4) flow run training.yaml     # Launch a job via YAML
+      1) flow tutorial                      # Guided setup
+      2) flow init                          # Configure API key
+      3) flow example gpu-test              # Verify GPU access
+      4) flow run examples/configs/basic.yaml  # Launch a job via YAML
 
     \b
     Core commands:
@@ -323,22 +316,26 @@ def cli(
         os.environ["FLOW_SIMPLE_OUTPUT"] = "1" if simple else "0"
 
     # Kick off non-blocking background prefetch early for UX wins
+    # Avoid skewing unit tests and non-interactive sessions with extra API calls
     try:
-        # Local import to avoid import cycles during CLI bootstrap
-        from flow.cli.utils.prefetch import start_prefetch_for_command
+        # Respect explicit opt-out
+        if os.environ.get("FLOW_PREFETCH", "1").strip() not in {"0", "false", "no"}:
+            # Only prefetch when attached to a TTY and not under pytest
+            if sys.stdout.isatty() and os.environ.get("PYTEST_CURRENT_TEST", "") == "":
+                # Local import to avoid import cycles during CLI bootstrap
+                from flow.cli.utils.prefetch import start_prefetch_for_command
 
-        start_prefetch_for_command()
+                start_prefetch_for_command()
     except Exception:
         # Best-effort; never block or fail CLI startup due to prefetch
         pass
 
-    # Demo mode: load persisted env and resolve state; defer banner to individual commands
+    # Demo mode: load persisted env (stateful control is via `flow demo ...`)
     try:
-        from flow.cli.utils.mode import apply_demo_mode, load_persistent_demo_env
+        from flow.cli.utils.mode import load_persistent_demo_env
 
         # Load ~/.flow/demo.env if present so demo start persists across commands
         load_persistent_demo_env()
-        apply_demo_mode(demo)
     except Exception:
         pass
 
@@ -385,20 +382,21 @@ def setup_cli() -> click.Group:
     lazy_commands: list[tuple[str, str, str, str]] = [
         ("tutorial", "tutorial", "Guided setup", "flow tutorial"),
         ("init", "init", "Configure credentials", "flow init"),
-        ("innit", "innit", "British alias for init", ""),
         ("demo", "demo", "Control demo mode", "flow demo on"),
+        ("docs", "docs", "Show documentation links", "flow docs --verbose"),
         ("status", "status", "List and monitor tasks", "flow status --watch"),
         ("dev", "dev", "Development environment", "flow dev"),
-        ("run", "run", "Submit task from YAML or command", "flow run training.yaml"),
+        ("run", "run", "Submit task from YAML or command", "flow run examples/configs/basic.yaml"),
         ("grab", "grab", "Quick resource selection", "flow grab 8 h100"),
-        ("cancel", "cancel", "Cancel tasks", "flow cancel :1"),
-        ("ssh", "ssh", "SSH into task", "flow ssh :1"),
-        ("logs", "logs", "View task logs", "flow logs :1 -f"),
+        ("cancel", "cancel", "Cancel tasks", "flow cancel 1"),
+        ("ssh", "ssh", "SSH into task", "flow ssh 1"),
+        ("ssh-simple", "ssh_simple", "Minimal SSH (no UI)", "flow ssh-simple 1"),
+        ("logs", "logs", "View task logs", "flow logs 1 -f"),
         ("volumes", "volumes", "Manage volumes", "flow volumes list"),
-        ("mount", "mount", "Attach volumes", "flow mount :1 myvol:/data"),
+        ("mount", "mount", "Attach volumes", "flow mount 1 myvol:/data"),
         ("ssh-keys", "ssh_keys", "Manage SSH keys", "flow ssh-keys list"),
-        ("ports", "ports", "Manage ports and tunnels", "flow ports open :1 --port 8080"),
-        ("upload-code", "upload_code", "Upload code to task", "flow upload-code :1"),
+        ("ports", "ports", "Manage ports and tunnels", "flow ports open 1 --port 8080"),
+        ("upload-code", "upload_code", "Upload code to task", "flow upload-code 1"),
         # ("reservations", "reservations", "Manage capacity reservations", "flow reservations list"),  # held
         # ("colab", "colab", "Colab local runtime", "flow colab"),  # held
         ("theme", "theme", "Manage CLI color themes", "flow theme set modern"),
@@ -412,8 +410,8 @@ def setup_cli() -> click.Group:
             # Support hyphen aliases by exposing module names that differ from command names
             # Use loader that imports on first invocation
             if isinstance(cli, LazyDYMGroup):
-                # Hide daemon in help to reduce surface area; still available by name
-                hidden = True if cli_name == "daemon" else None
+                # Hide some aliases in help to reduce surface area; still available by name
+                hidden = True if cli_name in {"daemon", "alloc"} else None
                 cli.add_lazy_command(cli_name, _loader(module_name), help_summary, example, hidden)
         except Exception:
             # Skip broken/optional commands silently
@@ -491,6 +489,21 @@ def main() -> int:
                 console.print("[yellow]⚠ Flow SDK is not configured[/yellow]\n")
                 console.print("To get started, run: [accent]flow init[/accent]")
                 console.print("Or set MITHRIL_API_KEY environment variable\n")
+                # Documentation link (with hyperlink support when available)
+                try:
+                    from flow.links import DocsLinks as _Docs
+                    from flow.cli.utils.hyperlink_support import hyperlink_support as _hs
+
+                    docs_url = _Docs.root()
+                    if _hs.is_supported():
+                        docs_link = _hs.create_link("Docs", docs_url)
+                        console.print(f"Documentation: {docs_link}  [dim](or run 'flow docs')[/dim]")
+                    else:
+                        console.print(
+                            f"Documentation: {docs_url}  [dim](or run 'flow docs')[/dim]"
+                        )
+                except Exception:
+                    pass
                 console.print("For help: [dim]flow --help[/dim]")
                 return 1
 
