@@ -4,12 +4,16 @@ This module contains the internal components used by the init command,
 separated to reduce file size while maintaining a clean public interface.
 """
 
-from .config_analyzer import ConfigAnalyzer, ConfigStatus, ConfigItem
-from .setup_components import (
+from flow.cli.commands._init_components.config_analyzer import (
+    ConfigAnalyzer,
+    ConfigItem,
+    ConfigStatus,
+)
+from flow.cli.commands._init_components.setup_components import (
+    AnimatedDots,
     ApiKeySetup,
     ProjectSetup,
     SshKeySetup,
-    AnimatedDots,
     select_from_options,
 )
 
