@@ -140,6 +140,13 @@ def select_from_options(
                     subtitle_parts.append(f"Created: {option['created_at']}")
                 if option.get("fingerprint"):
                     subtitle_parts.append(option["fingerprint"])
+                # Provide an explicit hint when we detect a matching local private key
+                try:
+                    display_name = option.get("display_name") or option.get("name") or ""
+                    if "(local copy)" in str(display_name):
+                        subtitle_parts.append("local private key present")
+                except Exception:
+                    pass
 
                 return SelectionItem(
                     value=option,
@@ -166,7 +173,7 @@ def select_from_options(
             return None
         return result if result else None
 
-    # Always try interactive selector first for better UX
+        # Always try interactive selector first for better UX
     try:
 
         def option_to_selection(option: dict[str, Any]) -> SelectionItem[dict[str, Any]]:
@@ -181,6 +188,12 @@ def select_from_options(
                     subtitle_parts.append(option["created_at"])
                 if "fingerprint" in option and option["fingerprint"]:
                     subtitle_parts.append(option["fingerprint"])
+                try:
+                    name_or_disp = option.get(name_key, option.get("name", ""))
+                    if "(local copy)" in str(name_or_disp):
+                        subtitle_parts.append("local private key present")
+                except Exception:
+                    pass
 
                 return SelectionItem(
                     value=option,
