@@ -313,13 +313,14 @@ class BeautifulTaskRenderer:
 
         lines.append("")  # Section separator
 
-        # SSH connection parameters for active tasks
-        if task.status.value == "running" and task.ssh_host:
+        # SSH connection parameters (show when available regardless of exact status)
+        if getattr(task, "ssh_host", None):
             lines.append("[bold accent]Connection:[/bold accent]")
             lines.append(f"  IP: {task.ssh_host}")
-            if task.ssh_port:
+            if getattr(task, "ssh_port", None):
                 lines.append(f"  Port: {task.ssh_port}")
-            lines.append(f"\n  [dim]flow ssh {task.name}[/dim]")
+            if getattr(task, "name", None):
+                lines.append(f"\n  [dim]flow ssh {task.name}[/dim]")
 
         # Temporal metadata
         lines.append("")
@@ -706,8 +707,8 @@ class AllocCommand(BaseCommand):
                     if has_active:
                         actions = [
                             "Inspect tasks: [accent]flow status[/accent]",
-                            "SSH into a task: [accent]flow ssh :1[/accent]",
-                            "Stream logs: [accent]flow logs :1 -f[/accent]",
+                            "SSH into a task: [accent]flow ssh 1[/accent]",
+                            "Stream logs: [accent]flow logs 1 -f[/accent]",
                         ]
                     else:
                         actions = [
