@@ -27,6 +27,7 @@ from rich.markup import escape
 
 from flow.cli.utils.theme_manager import theme_manager
 from flow.cli.commands.feedback import feedback
+from flow.cli.utils.next_steps import render_next_steps_panel
 
 console = theme_manager.create_console()
 
@@ -238,6 +239,22 @@ class BaseCommand(ABC):
         )
         console.print("[dim]Inspect current config:[/dim] [accent]flow init --show[/accent]")
 
+        # Centralized docs links and the new docs command
+        try:
+            from flow.links import DocsLinks as _Docs
+            from flow.cli.utils.hyperlink_support import hyperlink_support as _hs
+
+            doc_url = _Docs.root()
+            if _hs.is_supported():
+                doc_link = _hs.create_link("Docs", doc_url)
+                console.print(f"[dim]Documentation:[/dim] {doc_link}  [dim](or run 'flow docs')[/dim]")
+            else:
+                console.print(
+                    f"[dim]Documentation:[/dim] {doc_url}  [dim](or run 'flow docs')[/dim]"
+                )
+        except Exception:
+            pass
+
         raise click.exceptions.Exit(1)
 
     def show_next_actions(self, recommendations: list) -> None:
@@ -249,32 +266,5 @@ class BaseCommand(ABC):
         if not recommendations:
             return
 
-        from rich.panel import Panel
-        from flow.cli.utils.hyperlink_support import hyperlink_support
-
-        # Transform bracketed commands into hyperlinks when supported
-        processed: list[str] = []
-        for rec in recommendations:
-            try:
-                # Simple pattern: turn 'flow xyz' substrings into hyperlinks
-                if hyperlink_support.is_supported():
-                    parts = []
-                    for token in str(rec).split():
-                        if token == "flow":
-                            parts.append("[accent]flow[/accent]")
-                        else:
-                            parts.append(token)
-                    rec = " ".join(parts)
-            except Exception:
-                pass
-            processed.append(f"  • {rec}")
-
-        body = "\n".join(processed)
-        panel = Panel(
-            body,
-            title="[bold]Next steps[/bold]",
-            border_style=theme_manager.get_color("muted"),
-            expand=False,
-        )
-        console.print("\n")
-        console.print(panel)
+        # Use shared renderer for consistency with status view
+        render_next_steps_panel(console, [str(r) for r in recommendations])
