@@ -7,7 +7,7 @@ Examples:
     $ flow cancel my-training-job
 
     # Cancel last task from status (using index)
-    $ flow cancel :1
+    $ flow cancel 1
 
     # Cancel all dev tasks without confirmation (wildcard)
     $ flow cancel --name-pattern "dev-*" --yes
@@ -39,6 +39,7 @@ from flow.api.models import Task, TaskStatus
 from flow.cli.utils.task_formatter import TaskFormatter
 from flow.cli.utils.task_resolver import resolve_task_identifier as _resolve_task_identifier
 from flow.cli.utils.task_selector_mixin import TaskFilter, TaskOperationCommand
+from flow.cli.commands.utils import maybe_show_auto_status
 from flow.errors import AuthenticationError
 
 # Re-export for tests that patch 'flow.cli.commands.cancel.resolve_task_identifier'
@@ -232,6 +233,30 @@ class CancelCommand(BaseCommand, TaskOperationCommand):
                             console.print(
                                 f"[{error_color}]✗[/{error_color}] Failed to cancel {tid[:12]}…: {escape(str(e))}"
                             )
+                    # After batch, invalidate caches/snapshots and kick background refresh
+                    try:
+                        from flow.cli.utils.prefetch import (
+                            invalidate_cache_for_current_context as _inv_ctx,
+                            invalidate_snapshots as _inv_snap,
+                            refresh_active_task_caches as _rf_active,
+                            refresh_all_tasks_cache as _rf_all,
+                        )
+                        # Also clear index cache so :N mappings cannot target deleted tasks
+                        try:
+                            from flow.cli.utils.task_index_cache import TaskIndexCache as _TIC
+
+                            _TIC().clear()
+                        except Exception:
+                            pass
+
+                        _inv_ctx(["tasks_running", "tasks_pending", "tasks_all"])
+                        _inv_snap(["tasks_running", "tasks_pending", "tasks_all"])
+                        import threading as _th
+
+                        _th.Thread(target=_rf_active, daemon=True).start()
+                        _th.Thread(target=_rf_all, daemon=True).start()
+                    except Exception:
+                        pass
                     # Show next steps once after batch
                     self.show_next_actions(
                         [
@@ -313,11 +338,21 @@ class CancelCommand(BaseCommand, TaskOperationCommand):
         try:
             from flow.cli.utils.prefetch import (
                 invalidate_cache_for_current_context,
+                invalidate_snapshots,
                 refresh_active_task_caches,
                 refresh_all_tasks_cache,
             )
+            # Also clear index cache so :N mappings cannot point to deleted tasks
+            try:
+                from flow.cli.utils.task_index_cache import TaskIndexCache
+
+                TaskIndexCache().clear()
+            except Exception:
+                pass
 
             invalidate_cache_for_current_context(["tasks_running", "tasks_pending", "tasks_all"])
+            # Also drop on-disk snapshots so a fresh CLI process won't rehydrate stale lists
+            invalidate_snapshots(["tasks_running", "tasks_pending", "tasks_all"])
             import threading
 
             def _refresh():
@@ -331,6 +366,14 @@ class CancelCommand(BaseCommand, TaskOperationCommand):
         except Exception:
             pass
 
+        # Show a compact status snapshot after state change
+        try:
+            maybe_show_auto_status(
+                focus=(task.name or task.task_id), reason="After cancellation", show_all=False
+            )
+        except Exception:
+            pass
+
     def _show_cancel_confirmation(self, task: Task) -> None:
         """Show a confirmation panel with task details."""
         from datetime import datetime, timezone
