@@ -354,6 +354,21 @@ class ColabCommand(BaseCommand):
                     # Unified timeline for submission → allocation → SSH
                     timeline = StepTimeline(console, title="flow colab", title_animation="auto")
                     timeline.start()
+                    # Real provider safety guard (interactive only)
+                    try:
+                        from flow.cli.utils.real_provider_guard import ensure_real_provider_ack
+
+                        if not ensure_real_provider_ack(
+                            instance_type=instance_type,
+                            priority=None,
+                            max_price_per_hour=None,
+                            num_instances=1,
+                            auto_confirm=False,
+                        ):
+                            timeline.finish()
+                            return
+                    except Exception:
+                        pass
                     submit_idx = timeline.add_step(
                         f"Submitting {instance_type} request", show_bar=False
                     )
