@@ -102,7 +102,7 @@ class DevVMManager:
         logger.debug(f"Generated dev VM name: {vm_name} for user: {user}")
         return vm_name
 
-    def find_dev_vm(self, include_not_ready=False):
+    def find_dev_vm(self, include_not_ready: bool = False, region: str | None = None):
         """Find existing dev VM for current user.
 
         Args:
@@ -142,6 +142,13 @@ class DevVMManager:
             for task in tasks:
                 # Check both new and legacy naming patterns
                 if task.name.startswith(vm_prefix) or task.name.startswith(legacy_prefix):
+                    # Filter by region when specified
+                    try:
+                        if region and getattr(task, "region", None) and task.region != region:
+                            continue
+                    except Exception:
+                        # If region not present on task, don't filter it out
+                        pass
                     logger.debug(f"Found potential dev VM: {task.name} (ID: {task.task_id})")
                     # Separate ready and not-ready VMs
                     if task.ssh_host:
@@ -182,6 +189,7 @@ class DevVMManager:
     def create_dev_vm(
         self,
         instance_type: str = None,
+        region: str | None = None,
         ssh_keys: list = None,
         max_price_per_hour: float = None,
         no_unique: bool = False,
@@ -250,6 +258,10 @@ exec sleep infinity
             "priority": "high",  # High priority for dev VMs
         }
 
+        # Respect explicit region preference when provided
+        if region is not None:
+            config_dict["region"] = region
+
         # Add max_price_per_hour if specified
         if max_price_per_hour is not None:
             config_dict["max_price_per_hour"] = max_price_per_hour
@@ -634,7 +646,12 @@ Examples:
 
         @click.command(name=self.name, help=self.help)
         @click.argument("cmd_arg", required=False)  # Optional positional argument for command
-        @click.option("--command", "-c", help="Command to execute (VM or container)")
+        @click.option(
+            "--command",
+            "-c",
+            help="Command to execute (deprecated; pass command positionally)",
+            hidden=True,
+        )
         @click.option(
             "--env",
             "-e",
@@ -642,12 +659,17 @@ Examples:
             help="Environment: 'default' (VM) or named (container)",
         )
         @click.option("--instance-type", "-i", help="Instance type for dev VM (e.g., a100, h100)")
+        @click.option(
+            "--region",
+            "-r",
+            help="Preferred region for the dev VM (e.g., us-central1-b)",
+        )
         @click.option("--image", help="Docker image for container execution")
         @click.option(
             "--ssh-keys", "-k", multiple=True, help="SSH keys to use (can specify multiple)"
         )
         @click.option("--reset", "-r", is_flag=True, help="Reset all containers")
-        @click.option("--stop", "-S", "-s", is_flag=True, help="Stop the dev VM")
+        @click.option("--stop", "-S", is_flag=True, help="Stop the dev VM")
         @click.option("--info", "status", is_flag=True, help="Show dev environment status")
         @click.option(
             "--status", "status", is_flag=True, help="Show dev environment status", hidden=True
@@ -676,6 +698,7 @@ Examples:
             command: str | None,
             env: str,
             instance_type: str | None,
+            region: str | None,
             image: str | None,
             ssh_keys: tuple,
             reset: bool,
@@ -765,6 +788,7 @@ Examples:
                 command,
                 env,
                 instance_type,
+                region,
                 image,
                 ssh_keys,
                 reset,
@@ -785,6 +809,7 @@ Examples:
         command: str | None,
         env_name: str,
         instance_type: str | None,
+        region: str | None,
         image: str | None,
         ssh_keys: tuple,
         reset: bool,
@@ -839,6 +864,54 @@ Examples:
                 self._show_status(vm_manager, flow_client, output_json=output_json)
                 return
 
+            # Preflight SSH keys: compute effective keys and fail fast if none
+            try:
+                from flow._internal.config import Config as _Cfg
+                cfg = _Cfg.from_env(require_auth=True)
+                provider_cfg = cfg.provider_config if isinstance(cfg.provider_config, dict) else {}
+                effective_keys = []
+                # CLI-provided keys override
+                if ssh_keys:
+                    effective_keys = list(ssh_keys)
+                # Env overrides next (non-empty)
+                if not effective_keys:
+                    import os as _os
+                    env_keys = _os.getenv("MITHRIL_SSH_KEYS")
+                    if env_keys:
+                        parsed = [k.strip() for k in env_keys.split(",") if k.strip()]
+                        if parsed:
+                            effective_keys = parsed
+                # Provider config fallback
+                if not effective_keys:
+                    eff_cfg_keys = provider_cfg.get("ssh_keys") or []
+                    if isinstance(eff_cfg_keys, list):
+                        effective_keys = list(eff_cfg_keys)
+                if not effective_keys:
+                    from flow.cli.commands.base import console as _console
+                    _console.print(
+                        "\n[red]No SSH keys configured for dev VM[/red]"
+                    )
+                    _console.print(
+                        "[dim]Fix:[/dim] flow ssh-keys upload ~/.ssh/id_ed25519.pub  •  "
+                        "export MITHRIL_SSH_KEY=~/.ssh/id_ed25519  •  "
+                        "add mithril.ssh_keys to ~/.flow/config.yaml"
+                    )
+                    raise SystemExit(1)
+                else:
+                    try:
+                        from flow.cli.commands.base import console as _console
+                        keys_preview = ", ".join(effective_keys[:3])
+                        if len(effective_keys) > 3:
+                            keys_preview += f" (+{len(effective_keys)-3} more)"
+                        _console.print(f"[dim]Using SSH keys:[/dim] {keys_preview}")
+                    except Exception:
+                        pass
+            except SystemExit:
+                raise
+            except Exception:
+                # Never block; provider will still enforce non-empty later
+                pass
+
             # Unified timeline progress
             from flow.cli.utils.step_progress import (
                 AllocationProgressAdapter,
@@ -859,7 +932,7 @@ Examples:
             timeline.start()
 
             # Find or create dev VM - check for ANY existing VM first (ready or provisioning)
-            vm = vm_manager.find_dev_vm(include_not_ready=True)
+            vm = vm_manager.find_dev_vm(include_not_ready=True, region=region)
 
             if force_new and vm:
                 from flow.cli.utils.animated_progress import AnimatedEllipsisProgress
@@ -881,8 +954,9 @@ Examples:
                         baseline = int(getattr(vm, "instance_age_seconds", None) or 0)
                     except Exception:
                         baseline = 0
+                    # Clarify expected duration in label (up to DEFAULT_PROVISION_MINUTES)
                     step_idx_provision = timeline.add_step(
-                        "Provisioning VM & SSH",
+                        f"Waiting for SSH (up to {DEFAULT_PROVISION_MINUTES}m)",
                         show_bar=True,
                         estimated_seconds=DEFAULT_PROVISION_MINUTES * 60,
                         baseline_elapsed_seconds=baseline,
@@ -912,10 +986,25 @@ Examples:
                     raise
 
             if not vm:
+                # Real provider safety guard (interactive only)
+                try:
+                    from flow.cli.utils.real_provider_guard import ensure_real_provider_ack
+
+                    if not ensure_real_provider_ack(
+                        instance_type=instance_type,
+                        priority=None,
+                        max_price_per_hour=max_price_per_hour,
+                        num_instances=1,
+                        auto_confirm=False,
+                    ):
+                        return
+                except Exception:
+                    pass
                 # Update existing progress or create new one
                 # Create VM
                 vm = vm_manager.create_dev_vm(
                     instance_type=instance_type,
+                    region=region,
                     ssh_keys=list(ssh_keys) if ssh_keys else None,
                     max_price_per_hour=max_price_per_hour,
                     no_unique=no_unique,
@@ -963,7 +1052,7 @@ Examples:
                 except Exception:
                     baseline = 0
                 step_idx_provision = timeline.add_step(
-                    "Provisioning VM & SSH",
+                    f"Waiting for SSH (up to {DEFAULT_PROVISION_MINUTES}m)",
                     show_bar=True,
                     estimated_seconds=DEFAULT_PROVISION_MINUTES * 60,
                     baseline_elapsed_seconds=baseline,
@@ -1158,14 +1247,34 @@ Examples:
                     except Exception:
                         pass
 
-                # Use timeline step for connection
+                # Use timeline step for connection (and drive remote progress through it)
                 step_idx_connect = timeline.add_step("Connecting", show_bar=False)
                 timeline.start_step(step_idx_connect)
+
+                # Provide a lightweight adapter so remote_operations can update our step text
+                class _TimelineProgressProxy:
+                    def __init__(self, tl):
+                        self._tl = tl
+
+                    def update_message(self, message: str):
+                        try:
+                            self._tl.update_active(message=message)
+                        except Exception:
+                            # Never let progress updates break the flow
+                            pass
+
+                progress_proxy = _TimelineProgressProxy(timeline)
+
                 # Start in environment directory for named envs
                 shell_cmd = None
                 if env_name != "default":
-                    shell_cmd = f'bash -lc "mkdir -p /envs/{env_name} && cd /envs/{env_name} && exec bash -l"'
-                flow_client.shell(vm.task_id, command=shell_cmd, progress_context=None)
+                    shell_cmd = (
+                        f'bash -lc "mkdir -p /envs/{env_name} && cd /envs/{env_name} && exec bash -l"'
+                    )
+
+                flow_client.shell(
+                    vm.task_id, command=shell_cmd, progress_context=progress_proxy
+                )
                 timeline.complete_step()
 
             # Show helpful next actions
