@@ -42,6 +42,7 @@ from flow.cli.commands.base import BaseCommand, console
 from flow.cli.commands.utils import wait_for_task
 from flow.cli.utils.step_progress import AllocationProgressAdapter, StepTimeline
 from flow.errors import AuthenticationError, ValidationError
+from flow.cli.commands.utils import maybe_show_auto_status
 
 
 class GrabCommand(BaseCommand):
@@ -428,6 +429,12 @@ class GrabCommand(BaseCommand):
                     f"Connect when ready: [accent]flow ssh {name}[/accent]  |  Release: [accent]flow release {name}[/accent]"
                 )
 
+            # Show a compact status snapshot after submission or acquisition
+            try:
+                maybe_show_auto_status(focus=name, reason="After grab", show_all=False)
+            except Exception:
+                pass
+
         except AuthenticationError:
             self.handle_auth_error()
         except ValidationError as e:
