@@ -179,36 +179,8 @@ class InitCommand(BaseCommand):
                 os.environ["FLOW_PROVIDER"] = "mock"
 
             if verbose and not any([provider, api_key, project, region, api_url, dry_run, demo]):
-                console.print("\n[bold]Flow SDK Configuration Guide:[/bold]\n")
-                console.print("Interactive setup:")
-                console.print("  flow init                         # Step-by-step wizard")
-                console.print("  flow init --dry-run               # Preview without saving")
-                console.print(
-                    "  flow init --demo                  # Configure mock provider (no real instances)\n"
-                )
-
-                console.print("Direct configuration:")
-                console.print(
-                    "  flow init --provider mithril --api-key fkey_xxx --project myproject"
-                )
-                console.print("  flow init --region us-west-2      # Set default region")
-                console.print("  flow init --api-url https://custom.api.com  # Custom endpoint\n")
-
-                console.print("Environment variables (canonical):")
-                console.print("  export MITHRIL_API_KEY=fkey_xxx   # Set API key")
-                console.print("  export MITHRIL_PROJECT=myproject  # Set project")
-                console.print("  export MITHRIL_REGION=us-west-2   # Set region\n")
-
-                console.print("Configuration files:")
-                console.print("  ~/.flow/config.yaml               # User configuration")
-                console.print("  ./.flow/config.yaml               # Project configuration")
-                console.print("  $FLOW_CONFIG                      # Custom config path\n")
-
-                console.print("Next steps after init:")
-                console.print("  • Test connection: flow health")
-                console.print("  • Upload SSH keys: flow ssh-keys upload ~/.ssh/id_rsa.pub")
-                console.print("  • Run first task: flow run examples/hello-gpu.yaml")
-                console.print("  • Start dev environment: flow dev\n")
+                # Detailed, read-only explainer for init and SSH keys.
+                self._print_verbose_help()
                 return
 
             # Handle --show
@@ -278,6 +250,65 @@ class InitCommand(BaseCommand):
 
         return init
 
+    def _print_verbose_help(self) -> None:
+        """Print detailed, read-only help for `flow init --verbose`.
+
+        This explains what init configures, where files live, SSH key behavior,
+        configuration precedence, canonical environment variables, and useful
+        follow-up commands. It does not mutate any state.
+        """
+        console.print("\n[bold]Flow Init — Detailed Guide[/bold]\n")
+
+        console.print("[bold]What this configures[/bold]")
+        console.print("  - Provider (backend)")
+        console.print("  - API key (verified)")
+        console.print("  - Default project and region")
+        console.print("  - Default SSH key behavior")
+        console.print("[dim]Note: init never provisions resources.[/dim]\n")
+
+        console.print("[bold]Where configuration is saved[/bold]")
+        console.print("  - ~/.flow/config.yaml               # User configuration")
+        console.print("  - ./.flow/config.yaml               # Project override (optional)")
+        console.print("  - ~/.flow/env.sh                    # Optional: generated env script (source it with: source ~/.flow/env.sh)\n")
+
+        console.print("[bold]SSH keys[/bold]")
+        console.print("  - Recommended: Generate on Mithril.")
+        console.print("    Creates a key pair and saves the private key under ~/.flow/keys/ with secure permissions.")
+        console.print("    Private keys are never uploaded. You can also select an existing platform key or generate locally (uploads public key only).")
+        console.print("  - Existing local keys: ~/.ssh/ (id_ed25519, id_rsa, id_ecdsa)")
+        console.print("  - Configure once in ~/.flow/config.yaml:")
+        console.print("    provider: mithril")
+        console.print("    api_key: fkey_xxxxxxxxxxxxxxxxxxxxx")
+        console.print("    project: my-project")
+        console.print("    region: us-central1-b")
+        console.print("    ssh_keys:")
+        console.print("      # - sshkey_ABC123        # platform key ID (optional)")
+        console.print("      # - ~/.ssh/id_ed25519    # local private key path (optional)\n")
+
+        console.print("[bold]Configuration precedence[/bold]")
+        console.print("  1) Environment (canonical) → 2) Config files → 3) Interactive init\n")
+
+        console.print("[bold]Canonical environment variables[/bold]")
+        console.print("  - MITHRIL_API_KEY")
+        console.print("  - MITHRIL_PROJECT")
+        console.print("  - MITHRIL_REGION")
+        console.print("  - MITHRIL_SSH_KEYS    # comma-separated key IDs or paths")
+        console.print("  - MITHRIL_SSH_KEY     # absolute path to private key for SSH\n")
+
+        console.print("[bold]Useful commands[/bold]")
+        console.print("  - Discover/sync keys: flow ssh-keys list --sync")
+        console.print("  - Upload a local key: flow ssh-keys upload ~/.ssh/id_ed25519.pub")
+        console.print("  - Inspect a key:      flow ssh-keys details <sshkey_id>")
+        console.print("  - Health check:       flow health\n")
+
+        console.print("[bold]Provider specifics (Mithril)[/bold]")
+        console.print("  - SSH keys are per-project; admin-required keys (if any) are auto-included on launch.\n")
+
+        console.print("[bold]Next steps[/bold]")
+        console.print("  - flow health")
+        console.print("  - flow example gpu-test")
+        console.print("  - flow status\n")
+
     async def _init_async(
         self,
         provider: str | None,
