@@ -16,7 +16,7 @@ Examples:
         $ flow mount training-data gpu-job-1
 
     Mount using indices:
-        $ flow mount :1 :2
+        $ flow mount 1 2
 
     Mount with custom path:
         $ flow mount datasets ml-training --mount-point /data/training
@@ -158,7 +158,7 @@ class MountCommand(BaseCommand):
             Examples:
                 flow mount vol-abc123 my-task    # Mount by IDs/names
                 flow mount dataset training-job   # Mount by names
-                flow mount :1 :2                  # Mount by indices
+                flow mount 1 2                    # Mount by indices
                 flow mount -v data -t task -i 0   # Specific instance
                 flow mount vol-123 task-456 --mount-point /data/datasets  # Custom path
 
@@ -182,7 +182,7 @@ class MountCommand(BaseCommand):
                 console.print("  flow mount vol_abc123 task_xyz789       # By full IDs")
                 console.print("  flow mount training-data my-job         # By names")
                 console.print(
-                    "  flow mount :1 :2                        # By index from listings\n"
+                    "  flow mount 1 2                         # By index from listings\n"
                 )
 
                 console.print("Mount locations:")
