@@ -10,7 +10,7 @@ Examples:
     $ flow release grab-abc123
 
     # Release by index from status
-    $ flow release :1
+    $ flow release 1
 
     # Release all grabbed resources
     $ flow release --all
@@ -33,6 +33,7 @@ from flow.cli.commands.base import BaseCommand, console
 from flow.cli.utils.task_formatter import TaskFormatter
 from flow.cli.utils.task_selector_mixin import TaskOperationCommand
 from flow.errors import AuthenticationError
+from flow.cli.commands.utils import maybe_show_auto_status
 
 
 class ReleaseCommand(BaseCommand, TaskOperationCommand):
@@ -100,7 +101,7 @@ class ReleaseCommand(BaseCommand, TaskOperationCommand):
                 console.print("  flow release                      # Interactive with cost info")
                 console.print("  flow release train-v2             # By custom name")
                 console.print("  flow release grab-abc123          # By auto-generated name")
-                console.print("  flow release :1                   # By index from status\n")
+                console.print("  flow release 1                    # By index from status\n")
 
                 console.print("Batch operations:")
                 console.print("  flow release --all                # Release all grabbed")
@@ -208,6 +209,12 @@ class ReleaseCommand(BaseCommand, TaskOperationCommand):
             ]
         )
 
+        # Show a compact status snapshot after state change
+        try:
+            maybe_show_auto_status(focus=(task.name or task.task_id), reason="After release")
+        except Exception:
+            pass
+
     def _show_release_confirmation(self, task: Task) -> None:
         """Show a confirmation panel with resource details."""
         from datetime import datetime, timezone
