@@ -63,7 +63,7 @@ from flow.api.client import Flow
 from flow.api.models import TaskConfig
 from flow.cli.commands.base import BaseCommand, console
 from flow.cli.commands.messages import print_next_actions
-from flow.cli.commands.utils import display_config, wait_for_task
+from flow.cli.commands.utils import display_config, wait_for_task, maybe_show_auto_status
 from flow.cli.provider_resolver import ProviderResolver
 from flow.cli.utils.step_progress import (
     AllocationProgressAdapter,
@@ -105,6 +105,11 @@ Examples:
         @click.argument("config_file", required=False)
         @click.argument("extra_args", nargs=-1)
         @click.option("--instance-type", "-i", help="GPU instance type (e.g., a100, 8xa100, h100)")
+        @click.option(
+            "--region",
+            "-r",
+            help="Preferred region (e.g., us-central1-b)",
+        )
         @click.option(
             "--ssh-keys", "-k", multiple=True, help="SSH keys to use (can specify multiple)"
         )
@@ -115,7 +120,12 @@ Examples:
         )
         @click.option("--name", "-n", help="Task name (default: auto-generated)")
         @click.option("--no-unique", is_flag=True, help="Don't append unique suffix to task name")
-        @click.option("--command", "-c", help="Command to run (alternative to config file)")
+        @click.option(
+            "--command",
+            "-c",
+            help="Command to run (deprecated; pass command positionally or after --)",
+            hidden=True,
+        )
         @click.option(
             "--priority",
             "-p",
@@ -243,6 +253,7 @@ Examples:
         def run(
             config_file: str | None,
             instance_type: str | None,
+            region: str | None,
             ssh_keys: tuple[str, ...],
             image: str,
             name: str | None,
@@ -378,6 +389,7 @@ Examples:
             self._execute(
                 config_file,
                 instance_type,
+                region,
                 ssh_keys,
                 image,
                 name,
@@ -416,6 +428,7 @@ Examples:
         self,
         config_file: str | None,
         instance_type: str | None,
+        region: str | None,
         ssh_keys: tuple[str, ...],
         image: str,
         name: str | None,
@@ -596,7 +609,16 @@ Examples:
                             _data = yaml.safe_load(_f)
                         if not isinstance(_data, dict):
                             raise yaml.YAMLError("YAML must be a mapping of keys to values")
-                        _data.setdefault("unique_name", False)
+                        # Naming policy for YAML input:
+                        # - If user explicitly provided a name and did not specify unique_name,
+                        #   default to not modifying their name (unique_name=False).
+                        # - If no name provided and unique_name not specified, default to True so the
+                        #   model layer appends a short suffix for uniqueness.
+                        if "unique_name" not in _data:
+                            has_name = isinstance(_data.get("name"), str) and bool(
+                                (_data.get("name") or "").strip()
+                            )
+                            _data["unique_name"] = False if has_name else True
                         config = TaskConfig(**_data)
                     except FileNotFoundError:
                         self.handle_error(f"Configuration file does not exist: {config_file}")
@@ -614,6 +636,8 @@ Examples:
                     updated_configs = []
                     for cfg in configs:
                         updates = {}
+                        if region is not None:
+                            updates["region"] = region
                         if upload_strategy != "auto":
                             updates["upload_strategy"] = upload_strategy
                             updates["upload_timeout"] = upload_timeout
@@ -633,6 +657,8 @@ Examples:
                     configs = updated_configs
                 else:
                     updates = {}
+                    if region is not None:
+                        updates["region"] = region
                     if upload_strategy != "auto":
                         updates["upload_strategy"] = upload_strategy
                         updates["upload_timeout"] = upload_timeout
@@ -663,6 +689,7 @@ Examples:
 
                 config_dict = self._create_interactive_config(
                     instance_type,
+                    region,
                     ssh_keys,
                     image,
                     name,
@@ -825,6 +852,50 @@ Examples:
                         for target, source in mount_dict.items():
                             console.print(f"  {target} → {source}")
 
+            # Real provider safety guard before submission (interactive only; skip when output_json)
+            try:
+                if not output_json:
+                    from flow.cli.utils.real_provider_guard import ensure_real_provider_ack
+
+                    guard_instance_type = None
+                    guard_priority = None
+                    guard_max_price = None
+                    guard_num_instances = 1
+                    if is_slurm and configs:
+                        c0 = configs[0]
+                        guard_instance_type = getattr(c0, "instance_type", None)
+                        guard_priority = getattr(c0, "priority", None)
+                        guard_max_price = getattr(c0, "max_price_per_hour", None)
+                        try:
+                            guard_num_instances = int(getattr(c0, "num_instances", 1) or 1)
+                        except Exception:
+                            guard_num_instances = 1
+                    else:
+                        guard_instance_type = getattr(config, "instance_type", None)
+                        guard_priority = getattr(config, "priority", None)
+                        guard_max_price = getattr(config, "max_price_per_hour", None)
+                        try:
+                            guard_num_instances = int(getattr(config, "num_instances", 1) or 1)
+                        except Exception:
+                            guard_num_instances = 1
+
+                    if not ensure_real_provider_ack(
+                        instance_type=guard_instance_type,
+                        priority=guard_priority,
+                        max_price_per_hour=guard_max_price,
+                        num_instances=guard_num_instances,
+                        auto_confirm=False,
+                    ):
+                        if timeline:
+                            try:
+                                timeline.finish()
+                            except Exception:
+                                pass
+                        return
+            except Exception:
+                # Safety guard must never block execution
+                pass
+
             if dry_run:
                 if output_json:
                     if is_slurm:
@@ -862,6 +933,52 @@ Examples:
             except Exception:
                 pass
 
+            # Preflight SSH keys: compute effective keys and fail fast if none
+            try:
+                from flow._internal.config import Config as _Cfg
+                cfg = _Cfg.from_env(require_auth=True)
+                provider_cfg = cfg.provider_config if isinstance(cfg.provider_config, dict) else {}
+                effective_keys = []
+                # Task-level keys override
+                if getattr(config, "ssh_keys", None):
+                    effective_keys = list(getattr(config, "ssh_keys") or [])
+                # Env overrides next (non-empty)
+                if not effective_keys:
+                    import os as _os
+                    env_keys = _os.getenv("MITHRIL_SSH_KEYS")
+                    if env_keys:
+                        parsed = [k.strip() for k in env_keys.split(",") if k.strip()]
+                        if parsed:
+                            effective_keys = parsed
+                # Provider config fallback
+                if not effective_keys:
+                    eff_cfg_keys = provider_cfg.get("ssh_keys") or []
+                    if isinstance(eff_cfg_keys, list):
+                        effective_keys = list(eff_cfg_keys)
+                if not effective_keys:
+                    from flow.cli.commands.base import console as _console
+                    _console.print(
+                        "\n[red]No SSH keys configured for this run[/red]"
+                    )
+                    _console.print(
+                        "[dim]Fix:[/dim] flow ssh-keys upload ~/.ssh/id_ed25519.pub  •  "
+                        "export MITHRIL_SSH_KEY=~/.ssh/id_ed25519  •  "
+                        "add mithril.ssh_keys to ~/.flow/config.yaml"
+                    )
+                    raise click.exceptions.Exit(1)
+                else:
+                    try:
+                        from flow.cli.commands.base import console as _console
+                        keys_preview = ", ".join(effective_keys[:3])
+                        if len(effective_keys) > 3:
+                            keys_preview += f" (+{len(effective_keys)-3} more)"
+                        _console.print(f"[dim]Using SSH keys:[/dim] {keys_preview}")
+                    except Exception:
+                        pass
+            except Exception:
+                # Never block; provider will still enforce non-empty later
+                pass
+
             # Initialize Flow client only when we're ready to submit
             flow_client = Flow()
 
@@ -947,6 +1064,13 @@ Examples:
                     refresh_active_task_caches,
                     refresh_all_tasks_cache,
                 )
+                # Clear index cache so :N mappings don't reference pre-submit list
+                try:
+                    from flow.cli.utils.task_index_cache import TaskIndexCache as _TIC
+
+                    _TIC().clear()
+                except Exception:
+                    pass
 
                 invalidate_cache_for_current_context(
                     ["tasks_running", "tasks_pending", "tasks_all"]
@@ -1023,6 +1147,11 @@ Examples:
                         f"Cancel if needed: [accent]flow cancel {task_ref}[/accent]",
                     ],
                 )
+                # Show a compact status snapshot after submission
+                try:
+                    maybe_show_auto_status(focus=task_ref, reason="After submission", show_all=False)
+                except Exception:
+                    pass
                 return
 
             # Allocation step
@@ -1072,7 +1201,7 @@ Examples:
                     except Exception:
                         baseline = 0
                     prov_idx = timeline.add_step(
-                        "Provisioning & SSH",
+                        f"Waiting for SSH (up to {DEFAULT_PROVISION_MINUTES}m)",
                         show_bar=True,
                         estimated_seconds=DEFAULT_PROVISION_MINUTES * 60,
                         baseline_elapsed_seconds=baseline,
@@ -1203,6 +1332,11 @@ Examples:
                 except Exception:
                     pass
                 print_next_actions(console, recommendations)
+                # After successful launch, show compact status
+                try:
+                    maybe_show_auto_status(focus=task_ref, reason="After launch", show_all=False)
+                except Exception:
+                    pass
             elif status == "failed":
                 console.print("\n[red]✗[/red] Task failed to start")
                 print_next_actions(
@@ -1291,6 +1425,7 @@ Examples:
                 ("already in use" in msg.lower())
                 or ("already exists" in msg.lower())
                 or ("name conflict" in msg.lower())
+                or ("already used" in msg.lower())
             )
             if is_conflict and chosen_policy == "suffix":
                 import uuid as _uuid
@@ -1306,6 +1441,7 @@ Examples:
     def _create_interactive_config(
         self,
         instance_type: str,
+        region: str | None,
         ssh_keys: tuple[str, ...],
         image: str,
         name: str | None,
@@ -1333,26 +1469,30 @@ Examples:
         """
         from flow.cli.utils.name_generator import generate_unique_name
 
-        # Generate name if not provided
+        # Determine base name and uniqueness policy
+        prefix = "run" if command else "interactive"
         if not name:
-            # Auto-generate name with prefix
-            prefix = "run" if command else "interactive"
-            name = generate_unique_name(
-                prefix=prefix,
-                base_name=None,
-                add_unique=not no_unique,  # Add unique suffix unless --no-unique
-            )
-        # If name is provided, use it as-is (user knows what they want)
+            # User did not specify a name: use a base name and let the model append a suffix
+            name_value = prefix
+            unique_flag = not no_unique
+        else:
+            # User explicitly provided a name: do not alter it by default
+            name_value = name
+            unique_flag = False
 
         # Build config dictionary; keep env empty so --env merges are exact in tests
         config = {
-            "name": name,
-            "unique_name": False,  # We handle uniqueness ourselves with --no-unique
+            "name": name_value,
+            "unique_name": unique_flag,
             "instance_type": instance_type,
             "image": image,
             "env": {},
         }
 
+        # Respect explicit region preference when provided
+        if region is not None:
+            config["region"] = region
+
         # Set command based on user input
         if command:
             # User provided a command - use it
