@@ -6,14 +6,16 @@ Examples:
     Connect interactively:
         $ flow ssh task-abc123
 
-    Execute remote command:
+    Execute remote command (two supported forms):
         $ flow ssh task-abc123 -c 'nvidia-smi'
+        $ flow ssh task-abc123 -- nvidia-smi
 
     Check GPU utilization:
         $ flow ssh task-abc123 -c 'watch -n1 nvidia-smi'
 """
 
 import os
+import shlex
 
 import click
 
@@ -57,6 +59,7 @@ Quick connect:
 
 Remote commands:
   flow ssh task -c 'nvidia-smi'    # Check GPU status
+  flow ssh task -- nvidia-smi      # Alternate syntax using '--'
   flow ssh task -c 'htop'          # Monitor system resources
   flow ssh task --node 1           # Connect to specific node (multi-instance)"""
 
@@ -102,7 +105,7 @@ Remote commands:
                         [
                             "Switch to real provider: flow init --provider mithril",
                             "Disable demo for this run: FLOW_DEMO_MODE=0 flow ssh ...",
-                            "Open logs instead: flow logs :1 -f",
+                            "Open logs instead: flow logs 1 -f",
                         ]
                     )
                 else:
@@ -117,8 +120,9 @@ Remote commands:
         timeline = StepTimeline(console, title="flow ssh", title_animation="auto")
         timeline.start()
 
-        # Step 1: Ensure SSH readiness if needed
-        if not task.ssh_host:
+        # Step 1: Ensure SSH readiness if needed (skip when FAST mode is enabled)
+        fast_mode = os.environ.get("FLOW_SSH_FAST") == "1"
+        if not fast_mode and not task.ssh_host:
             from flow.api.ssh_utils import DEFAULT_PROVISION_MINUTES, SSHNotReadyError
 
             # Seed bar from existing instance age so resume after Ctrl+C is realistic
@@ -128,7 +132,7 @@ Remote commands:
             except Exception:
                 baseline = 0
             step_idx = timeline.add_step(
-                "Provisioning & SSH",
+                f"Waiting for SSH (up to {DEFAULT_PROVISION_MINUTES}m)",
                 show_bar=True,
                 estimated_seconds=DEFAULT_PROVISION_MINUTES * 60,
                 baseline_elapsed_seconds=baseline,
@@ -167,9 +171,26 @@ Remote commands:
                 timeline.finish()
                 raise SystemExit(1)
 
-        # Now we have an IP, update display
+        # Refresh task to ensure we have the freshest SSH endpoint/user right before connect
+        try:
+            task = client.get_task(task.task_id)
+        except Exception:
+            pass
+        # Now we have an up-to-date view, update display
         task_display = self.task_formatter.format_task_display(task)
 
+        # Fresh-resolve endpoint via provider resolver to avoid any stale Task views
+        try:
+            host, port = client.provider.resolve_ssh_endpoint(task.task_id, node=node)
+            try:
+                setattr(task, "ssh_host", host)
+                setattr(task, "ssh_port", int(port or 22))
+            except Exception:
+                setattr(task, "ssh_port", 22)
+        except Exception:
+            # Best-effort; remote operations will still resolve before connecting
+            pass
+
         # Step 2: Connect or execute
         try:
             if command:
@@ -178,21 +199,12 @@ Remote commands:
                 client.shell(task.task_id, command=command, node=node, progress_context=None)
                 timeline.complete_step()
             else:
-                step_idx = timeline.add_step("Connecting", show_bar=False)
-                timeline.start_step(step_idx)
-                # Hint: safe exit from connection attempt
-                from flow.cli.utils.theme_manager import theme_manager
-
-                accent = theme_manager.get_color("accent")
-                from rich.text import Text
-
-                conn_hint = Text()
-                conn_hint.append("  Press ")
-                conn_hint.append("Ctrl+C", style=accent)
-                conn_hint.append(" to cancel connect attempt. Instance stays running.")
-                timeline.set_active_hint_text(conn_hint)
+                # Close the timeline before handing terminal control to SSH to prevent overlay
+                try:
+                    timeline.finish()
+                except Exception:
+                    pass
                 client.shell(task.task_id, node=node, progress_context=None)
-                timeline.complete_step()
         except Exception as e:
             # Show manual connection hint once
             try:
@@ -210,7 +222,15 @@ Remote commands:
                     f"\n[{warn}]Connection failed. You can try connecting manually with:[/{warn}]"
                 )
                 console.print(f"  {connection_cmd}\n")
-            timeline.fail_step(str(e))
+            # If the error carries a request/correlation ID, include it in the failure line
+            try:
+                req_id = getattr(e, "request_id", None)
+                if req_id:
+                    timeline.fail_step(f"{str(e)}\nRequest ID: {req_id}")
+                else:
+                    timeline.fail_step(str(e))
+            except Exception:
+                timeline.fail_step(str(e))
             timeline.finish()
             raise
 
@@ -234,13 +254,25 @@ Remote commands:
 
         @click.command(name=self.name, help=self.help)
         @click.argument("task_identifier", required=False, shell_complete=complete_task_ids)
-        @click.option("--command", "-c", help="Command to run on remote host")
+        @click.option(
+            "--command",
+            "-c",
+            help="Command to run on remote host (deprecated; prefer trailing command after --)",
+            hidden=True,
+        )
         @click.option(
             "--node", type=int, default=0, help="Node index for multi-instance tasks (default: 0)"
         )
         @click.option("--verbose", "-v", is_flag=True, help="Show detailed help and examples")
         @demo_aware_command()
-        def ssh(task_identifier: str | None, command: str | None, node: int, verbose: bool):
+        @click.argument("remote_cmd", nargs=-1)
+        def ssh(
+            task_identifier: str | None,
+            command: str | None,
+            node: int,
+            verbose: bool,
+            remote_cmd: tuple[str, ...],
+        ):
             """SSH to a running task.
 
             TASK_IDENTIFIER: Task ID or name (optional - interactive selector if omitted)
@@ -250,7 +282,8 @@ Remote commands:
                 flow ssh                    # Interactive task selector
                 flow ssh my-training        # Connect by name
                 flow ssh task-abc123        # Connect by ID
-                flow ssh task -c 'nvidia-smi'  # Run command remotely
+                flow ssh task -c 'nvidia-smi'           # Run command remotely (flag)
+                flow ssh task -- nvidia-smi             # Run command remotely (after --)
 
             Use 'flow ssh --verbose' for troubleshooting and advanced examples.
             """
@@ -288,6 +321,23 @@ Remote commands:
                 console.print("  • Task terminated? Check: flow status <name>\n")
                 return
 
+            # If a trailing command was provided after '--', prefer it over -c
+            # but guard against both being set to avoid ambiguity.
+            if remote_cmd:
+                if command:
+                    from flow.cli.utils.theme_manager import theme_manager as _tm_err3
+
+                    err_color = _tm_err3.get_color("error")
+                    console.print(
+                        f"[{err_color}]Specify either -c/--command or a trailing command after '--', not both[/{err_color}]"
+                    )
+                    return
+                # Reconstruct the remote command string with safe quoting
+                try:
+                    command = shlex.join(remote_cmd)
+                except Exception:
+                    command = " ".join(remote_cmd)
+
             # Selection support (works after 'flow status')
             if task_identifier:
                 from flow.cli.utils.selection_helpers import parse_selection_to_task_ids
