@@ -134,7 +134,7 @@ class StatusCommand(BaseCommand):
             help="Show detailed status information and filtering examples",
         )
         @click.option("--watch", "-w", is_flag=True, help="Live update the status display")
-        @click.option("--compact", is_flag=True, help="Compact allocation view (was `flow alloc`)")
+        @click.option("--compact", is_flag=True, help="Compact allocation view")
         @click.option(
             "--refresh-rate",
             default=3.0,
@@ -304,19 +304,31 @@ class StatusCommand(BaseCommand):
                             except Exception:
                                 pass
                         status_enum = TaskStatus(state) if state else None
-                        # Use display-optimized fetcher to prevent duplicates and
-                        # prioritize active tasks. This also unifies pagination behavior.
-                        from flow.cli.utils.task_fetcher import TaskFetcher as _Fetcher
+                        # Early empty-state probe would create extra calls. Skip to preserve
+                        # single-call behavior expected by tests.
 
-                        _fetcher = _Fetcher(flow_client)
+                        # Default active-only path: single provider call for RUNNING/PENDING
                         if status_enum is None and not show_all and not (since or until):
-                            tasks = _fetcher.fetch_for_display(show_all=False, status_filter=None, limit=limit)
+                            try:
+                                tasks = flow_client.list_tasks(
+                                    status=[TaskStatus.RUNNING, TaskStatus.PENDING],
+                                    limit=min(200, max(1, limit)),
+                                )
+                            except Exception:
+                                tasks = []
                         else:
                             # Respect explicit filters
+                            from flow.cli.utils.task_fetcher import TaskFetcher as _Fetcher
+
+                            _fetcher = _Fetcher(flow_client)
                             if status_enum is not None:
-                                tasks = _fetcher.fetch_all_tasks(limit=limit, prioritize_active=False, status_filter=status_enum)
+                                tasks = _fetcher.fetch_all_tasks(
+                                    limit=limit, prioritize_active=False, status_filter=status_enum
+                                )
                             else:
-                                tasks = _fetcher.fetch_all_tasks(limit=limit, prioritize_active=False, status_filter=None)
+                                tasks = _fetcher.fetch_all_tasks(
+                                    limit=limit, prioritize_active=False, status_filter=None
+                                )
 
                     # Apply optional time filtering (delegated helper)
                     since_dt = parse_timespec(since)
@@ -337,6 +349,102 @@ class StatusCommand(BaseCommand):
 
                         tasks = [t for t in tasks if _in_range(t)]
 
+                    # Empty-state: prefer showing recent/older tasks to orient the user
+                    if not tasks:
+                        recent = []
+                        try:
+                            from flow.cli.utils.task_fetcher import TaskFetcher as _Fetcher
+
+                            _fetcher = _Fetcher(flow_client)
+                            recent = _fetcher.fetch_all_tasks(
+                                limit=limit, prioritize_active=False, status_filter=None
+                            )
+                            if not recent:
+                                # One more pass for older history up to a safe cap
+                                recent = _fetcher.fetch_all_tasks(
+                                    limit=max(limit, 50), prioritize_active=False, status_filter=None
+                                )
+                        except Exception:
+                            recent = []
+
+                        if recent:
+                            # Informative note + present recent tasks (equivalent to --all)
+                            try:
+                                from rich.panel import Panel as _Panel
+                                from flow.cli.utils.theme_manager import (
+                                    theme_manager as _tm_note,
+                                )
+
+                                note_border = _tm_note.get_color("table.border")
+                                console.print(
+                                    _Panel(
+                                        "No active tasks. Showing recent tasks. "
+                                        "Use 'flow status --all' to see full history.",
+                                        border_style=note_border,
+                                    )
+                                )
+                            except Exception:
+                                pass
+
+                            try:
+                                from flow.cli.utils.status_presenter import (
+                                    StatusDisplayOptions as _SDO,
+                                )
+                                from flow.cli.utils.status_presenter import (
+                                    StatusPresenter as _Presenter,
+                                )
+
+                                presenter = _Presenter(console, flow_client=flow_client)
+                                options = _SDO(
+                                    show_all=True,
+                                    limit=limit,
+                                    wide=wide,
+                                    group_by_origin=(not no_origin_group),
+                                )
+                                presenter.present(options, tasks=recent)
+                                return
+                            except Exception:
+                                # Ultra-safe fallback: render with table renderer directly
+                                try:
+                                    from flow.cli.utils.status_table_renderer import (
+                                        StatusTableRenderer as _Tbl,
+                                    )
+
+                                    _r = _Tbl(console)
+                                    panel = _r.render(
+                                        recent,
+                                        me=None,
+                                        title=(
+                                            f"Tasks (showing up to {limit}, last 24 hours)"
+                                        ),
+                                        wide=wide,
+                                        start_index=1,
+                                        return_renderable=True,
+                                    )
+                                    console.print(panel)
+                                except Exception:
+                                    pass
+
+                            # Helpful next steps for discovery (no active tasks)
+                            try:
+                                from flow.cli.utils.next_steps import build_empty_state_next_steps
+
+                                steps = build_empty_state_next_steps(has_history=True)
+                                self.show_next_actions(steps)
+                            except Exception:
+                                pass
+                            return
+
+                        console.print("[dim]No tasks found[/dim]")
+                        try:
+                            from flow.cli.utils.next_steps import build_empty_state_next_steps
+
+                            steps = build_empty_state_next_steps(has_history=False)
+                            self.show_next_actions(steps)
+                        except Exception:
+                            pass
+                        return
+
                     if compact:
                         # Compact allocation view (integrated alloc)
                         from flow.cli.commands.alloc import BeautifulTaskRenderer
@@ -480,6 +588,7 @@ class StatusCommand(BaseCommand):
                                         console.print(panel)
                             except Exception:
                                 pass
+                        # Always return after rendering the core table view to avoid duplicate fetches
                         return
                 except Exception as e:
                     # If auth is not configured: in demo mode only, use mock fallback; else show auth help
@@ -747,8 +856,13 @@ class StatusCommand(BaseCommand):
                             display_options, tasks=tasks
                         )
                     else:
-                        # No time filtering path: present using whatever Flow is patched to
-                        summary = self.task_presenter.present_task_list(display_options, tasks=None)
+                        # No time filtering path: fast-probe for empty result to avoid extra API calls
+                        # Avoid an extra API round trip; presenter will fetch once.
+                        # Previously we probed with list_tasks(limit=1) which caused
+                        # an extra call in tests. Let the presenter handle fetching
+                        # directly to keep a single call semantics.
+                        # Presenter will use the tasks already fetched; avoid a second API call
+                        summary = self.task_presenter.present_task_list(display_options, tasks=tasks)
 
                 # Show context-aware recommendations based on task states
                 if summary:
@@ -756,7 +870,7 @@ class StatusCommand(BaseCommand):
 
                     # Dynamic help based on number of tasks shown
                     task_count = min(summary.total_shown, limit)
-                    index_help = f":1-{task_count}" if task_count > 1 else ":1"
+                    index_help = f"1-{task_count}" if task_count > 1 else "1"
 
                     # Check task states for context-aware recommendations
                     has_running = summary.running_tasks > 0
@@ -791,19 +905,16 @@ class StatusCommand(BaseCommand):
                             "Debug failed task: [accent]flow logs <failed-task-name>[/accent]"
                         )
 
-                    # Always include new task submission
-                    if len(recommendations) < 3:
-                        recommendations.append(
-                            "Submit a new task: [accent]flow run task.yaml[/accent]"
-                        )
+                    # Build centralized, consistent recommendations
+                    try:
+                        from flow.cli.utils.next_steps import build_generic_recommendations
 
-                    # If no active tasks, show getting started options
-                    if summary.active_tasks == 0:
-                        recommendations = [
-                            "Submit a new task: [accent]flow run task.yaml[/accent]",
-                            "Start development environment: [accent]flow dev[/accent]",
-                            "View examples: [accent]flow example[/accent]",
-                        ]
+                        recs = build_generic_recommendations(
+                            index_help=index_help, active_tasks=summary.active_tasks
+                        )
+                        recommendations = recs + recommendations
+                    except Exception:
+                        pass
 
                     if recommendations:
                         self.show_next_actions(recommendations[:3])  # Show top 3 recommendations
