@@ -5,55 +5,49 @@ or check for available updates without installing them.
 """
 
 import json
+import re
 import subprocess
 import sys
-from importlib.metadata import version as get_version
+import os
 from pathlib import Path
-from typing import Optional, Tuple
+from datetime import datetime
 
 import click
 import requests
-from packaging import version
-from rich.console import Console
+from rich.markup import escape
 from rich.panel import Panel
 from rich.table import Table
 
-from .base import BaseCommand
+from flow._version import get_version as get_sdk_version
+from flow.cli.commands.base import BaseCommand
+from flow.cli.utils.theme_manager import theme_manager
 
-console = Console()
+console = theme_manager.create_console()
 
 
 class UpdateChecker:
-    """Check for and install Flow SDK updates."""
+    """Check for and install Flow SDK updates.
+
+    When `quiet` is True, suppresses all console output so callers can
+    implement their own output formatting (e.g., JSON mode).
+    """
 
     PYPI_API_URL = "https://pypi.org/pypi/flow-compute/json"
     PACKAGE_NAME = "flow-compute"
 
-    def __init__(self):
+    def __init__(self, quiet: bool = False):
         self.current_version = self._get_current_version()
-        self.latest_version = None
-        self.available_versions = []
+        self.latest_version: str | None = None
+        self.available_versions: list[str] = []
+        self.quiet = quiet
+        self.last_error: str | None = None
 
     def _get_current_version(self) -> str:
         """Get the currently installed version."""
-        try:
-            return get_version(self.PACKAGE_NAME)
-        except Exception:
-            # Fallback to reading from pyproject.toml if in development
-            try:
-                pyproject_path = (
-                    Path(__file__).parent.parent.parent.parent.parent / "pyproject.toml"
-                )
-                if pyproject_path.exists():
-                    with open(pyproject_path) as f:
-                        for line in f:
-                            if line.startswith("version"):
-                                return line.split("=")[1].strip().strip('"')
-            except Exception:
-                pass
-            return "0.0.0"
+        # Use the shared version helper for consistency across CLI and library
+        return get_sdk_version()
 
-    def check_for_updates(self) -> Tuple[bool, Optional[str], Optional[str]]:
+    def check_for_updates(self) -> tuple[bool, str | None, str | None]:
         """Check if updates are available.
 
         Returns:
@@ -73,7 +67,7 @@ class UpdateChecker:
                     non_yanked_versions.append(ver)
 
             self.available_versions = sorted(
-                non_yanked_versions, key=lambda v: version.parse(v), reverse=True
+                non_yanked_versions, key=lambda v: _parse_version(v), reverse=True
             )
 
             # PyPI's info.version might be yanked, so use the latest non-yanked version
@@ -96,8 +90,8 @@ class UpdateChecker:
                 )
 
             # Compare versions
-            current = version.parse(self.current_version)
-            latest = version.parse(self.latest_version)
+            current = _parse_version(self.current_version)
+            latest = _parse_version(self.latest_version)
 
             # Get release URL
             release_url = f"https://pypi.org/project/{self.PACKAGE_NAME}/{self.latest_version}/"
@@ -105,10 +99,14 @@ class UpdateChecker:
             return latest > current, self.latest_version, release_url
 
         except requests.exceptions.RequestException as e:
-            console.print(f"[red]Error checking for updates: {e}[/red]")
+            self.last_error = str(e)
+            if not self.quiet:
+                console.print(f"[red]Error checking for updates: {escape(str(e))}[/red]")
             return False, None, None
         except Exception as e:
-            console.print(f"[red]Unexpected error: {e}[/red]")
+            self.last_error = str(e)
+            if not self.quiet:
+                console.print(f"[red]Unexpected error: {escape(str(e))}[/red]")
             return False, None, None
 
     def get_version_info(self, version_str: str) -> dict:
@@ -161,7 +159,7 @@ class UpdateChecker:
         elif "uv" in sys.executable or Path(sys.executable).parent.name == "uv":
             env_info["installer"] = "uv"
             env_info["update_command"] = f"uv pip install --upgrade {self.PACKAGE_NAME}"
-        elif "pipx" in str(Path(sys.executable).parent):
+        elif "/pipx/venvs/" in sys.executable or "/pipx/venvs/" in str(Path(sys.executable)) or os.getenv("PIPX_HOME") or os.getenv("PIPX_BIN_DIR"):
             env_info["installer"] = "pipx"
             env_info["update_command"] = f"pipx upgrade {self.PACKAGE_NAME}"
         else:
@@ -170,26 +168,27 @@ class UpdateChecker:
                 f"{sys.executable} -m pip install --upgrade {self.PACKAGE_NAME}"
             )
 
-        # Check write permissions
-        try:
-            import site
+        # Check write permissions only for system pip installs; uv and pipx manage user locations
+        if env_info["installer"] == "pip":
+            try:
+                import site
 
-            site_packages = site.getsitepackages()[0] if site.getsitepackages() else None
-            if site_packages:
-                test_file = Path(site_packages) / ".flow_update_test"
-                try:
-                    test_file.touch()
-                    test_file.unlink()
-                except (PermissionError, OSError):
-                    env_info["can_update"] = False
-                    if not env_info["is_virtual"]:
-                        env_info["update_command"] = f"sudo {env_info['update_command']}"
-        except Exception:
-            pass
+                site_packages = site.getsitepackages()[0] if site.getsitepackages() else None
+                if site_packages:
+                    test_file = Path(site_packages) / ".flow_update_test"
+                    try:
+                        test_file.touch()
+                        test_file.unlink()
+                    except (PermissionError, OSError):
+                        env_info["can_update"] = False
+                        if not env_info["is_virtual"]:
+                            env_info["update_command"] = f"sudo {env_info['update_command']}"
+            except Exception:
+                pass
 
         return env_info
 
-    def perform_update(self, target_version: Optional[str] = None, force: bool = False) -> bool:
+    def perform_update(self, target_version: str | None = None, force: bool = False) -> bool:
         """Perform the actual update.
 
         Args:
@@ -202,8 +201,10 @@ class UpdateChecker:
         env_info = self.detect_environment()
 
         if not env_info["can_update"] and not force:
-            console.print("[red]Insufficient permissions to update.[/red]")
-            console.print(f"[yellow]Try running: {env_info['update_command']}[/yellow]")
+            self.last_error = "Insufficient permissions to update"
+            if not self.quiet:
+                console.print("[red]Insufficient permissions to update.[/red]")
+                console.print(f"[yellow]Try running: {env_info['update_command']}[/yellow]")
             return False
 
         # Build update command
@@ -230,28 +231,41 @@ class UpdateChecker:
             if force:
                 cmd.append("--force-reinstall")
 
-        console.print(f"[cyan]Running: {' '.join(cmd)}[/cyan]")
+        if not self.quiet:
+            console.print(f"[accent]Running: {' '.join(cmd)}[/accent]")
 
         try:
             result = subprocess.run(cmd, capture_output=True, text=True, check=False)
 
             if result.returncode == 0:
-                console.print("[green]✓ Update completed successfully![/green]")
+                if not self.quiet:
+                    success_color = theme_manager.get_color("success")
+                    console.print(
+                        f"[{success_color}]✓ Update completed successfully![/{success_color}]"
+                    )
                 return True
             else:
-                console.print(f"[red]Update failed with exit code {result.returncode}[/red]")
-                if result.stderr:
-                    console.print(f"[red]Error: {result.stderr}[/red]")
+                self.last_error = result.stderr or f"Exit code {result.returncode}"
+                if not self.quiet:
+                    console.print(
+                        f"[red]Update failed with exit code {escape(str(result.returncode))}[/red]"
+                    )
+                    if result.stderr:
+                        console.print(f"[red]Error: {escape(result.stderr)}[/red]")
                 return False
 
         except subprocess.SubprocessError as e:
-            console.print(f"[red]Failed to run update command: {e}[/red]")
+            self.last_error = str(e)
+            if not self.quiet:
+                console.print(f"[red]Failed to run update command: {escape(str(e))}[/red]")
             return False
         except Exception as e:
-            console.print(f"[red]Unexpected error during update: {e}[/red]")
+            self.last_error = str(e)
+            if not self.quiet:
+                console.print(f"[red]Unexpected error during update: {escape(str(e))}[/red]")
             return False
 
-    def create_backup(self) -> Optional[str]:
+    def create_backup(self) -> str | None:
         """Create a backup of current version info for rollback.
 
         Returns:
@@ -259,21 +273,24 @@ class UpdateChecker:
         """
         backup_info = {
             "version": self.current_version,
-            "timestamp": str(Path.cwd()),
+            "timestamp": datetime.utcnow().isoformat() + "Z",
+            "cwd": str(Path.cwd()),
             "environment": self.detect_environment(),
         }
 
         backup_dir = Path.home() / ".flow" / "backups"
         backup_dir.mkdir(parents=True, exist_ok=True)
 
-        backup_file = backup_dir / f"backup_{self.current_version}.json"
+        ts_slug = backup_info["timestamp"].replace(":", "").replace("-", "").replace(".", "")
+        backup_file = backup_dir / f"backup_{self.current_version}_{ts_slug}.json"
 
         try:
             with open(backup_file, "w") as f:
                 json.dump(backup_info, f, indent=2)
             return str(backup_file)
         except Exception as e:
-            console.print(f"[yellow]Warning: Could not create backup: {e}[/yellow]")
+            if not self.quiet:
+                console.print(f"[yellow]Warning: Could not create backup: {e}[/yellow]")
             return None
 
     def rollback(self, backup_file: str) -> bool:
@@ -290,12 +307,14 @@ class UpdateChecker:
                 backup_info = json.load(f)
 
             target_version = backup_info["version"]
-            console.print(f"[cyan]Rolling back to version {target_version}...[/cyan]")
+            if not self.quiet:
+                console.print(f"[accent]Rolling back to version {target_version}...[/accent]")
 
             return self.perform_update(target_version=target_version, force=True)
 
         except Exception as e:
-            console.print(f"[red]Rollback failed: {e}[/red]")
+            if not self.quiet:
+                console.print(f"[red]Rollback failed: {escape(str(e))}[/red]")
             return False
 
 
@@ -321,8 +340,8 @@ class UpdateCommand(BaseCommand):
         def update(
             check: bool,
             force: bool,
-            version: Optional[str],
-            rollback: Optional[str],
+            version: str | None,
+            rollback: str | None,
             yes: bool,
             output_json: bool,
         ):
@@ -335,13 +354,16 @@ class UpdateCommand(BaseCommand):
                 flow update --version 0.0.5  # Install specific version
                 flow update --force      # Force reinstall
             """
-            checker = UpdateChecker()
+            checker = UpdateChecker(quiet=output_json)
 
             # Handle rollback
             if rollback:
                 if output_json:
                     success = checker.rollback(rollback)
-                    print(json.dumps({"success": success}))
+                    payload = {"success": success}
+                    if not success and checker.last_error:
+                        payload["error"] = checker.last_error
+                    print(json.dumps(payload))
                 else:
                     success = checker.rollback(rollback)
                     if not success:
@@ -354,11 +376,19 @@ class UpdateCommand(BaseCommand):
             if check:
                 # Just check, don't update
                 if output_json:
+                    env_info = checker.detect_environment()
                     result = {
                         "current_version": checker.current_version,
                         "latest_version": latest_version,
                         "update_available": update_available,
                         "release_url": release_url,
+                        "environment": {
+                            "installer": env_info.get("installer"),
+                            "can_update": env_info.get("can_update"),
+                            "update_command": env_info.get("update_command"),
+                            "is_virtual": env_info.get("is_virtual"),
+                            "python_version": env_info.get("python_version"),
+                        },
                     }
                     print(json.dumps(result, indent=2))
                 else:
@@ -368,8 +398,30 @@ class UpdateCommand(BaseCommand):
             # Perform update
             if version:
                 # Install specific version
+                # Validate the requested version exists on PyPI
+                ver_info = checker.get_version_info(version)
+                if not ver_info:
+                    if output_json:
+                        print(
+                            json.dumps(
+                                {
+                                    "success": False,
+                                    "error": f"Version '{version}' not found on PyPI",
+                                    "previous_version": checker.current_version,
+                                },
+                                indent=2,
+                            )
+                        )
+                        raise click.exceptions.Exit(1)
+                    else:
+                        console.print(
+                            f"[red]Requested version '{escape(version)}' not found on PyPI[/red]"
+                        )
+                        raise click.exceptions.Exit(1)
+
                 target = version
-                console.print(f"[cyan]Installing Flow SDK version {target}...[/cyan]")
+                if not output_json:
+                    console.print(f"[accent]Installing Flow SDK version {target}...[/accent]")
             elif not update_available and not force:
                 if output_json:
                     print(
@@ -382,8 +434,9 @@ class UpdateCommand(BaseCommand):
                         )
                     )
                 else:
+                    success_color = theme_manager.get_color("success")
                     console.print(
-                        f"[green]✓ You're already on the latest version ({checker.current_version})[/green]"
+                        f"[{success_color}]✓ You're already on the latest version ({checker.current_version})[/{success_color}]"
                     )
                 return
             else:
@@ -415,6 +468,25 @@ class UpdateCommand(BaseCommand):
             if backup_file and not output_json:
                 console.print(f"[dim]Backup saved to: {backup_file}[/dim]")
 
+            # If PyPI check failed and no explicit version was requested, bail unless forced
+            if not version and latest_version is None and not force:
+                if output_json:
+                    print(
+                        json.dumps(
+                            {
+                                "success": False,
+                                "error": "Unable to determine latest version from PyPI; use --force or specify --version",
+                                "previous_version": checker.current_version,
+                            },
+                            indent=2,
+                        )
+                    )
+                else:
+                    console.print(
+                        "[red]Unable to determine latest version from PyPI. Use --force or specify --version.[/red]"
+                    )
+                raise click.exceptions.Exit(1)
+
             # Perform update
             success = checker.perform_update(target_version=version, force=force)
 
@@ -425,11 +497,18 @@ class UpdateCommand(BaseCommand):
                     "target_version": target or latest_version,
                     "backup_file": backup_file,
                 }
+                if not success and checker.last_error:
+                    result["error"] = checker.last_error
                 print(json.dumps(result, indent=2))
+                if not success:
+                    raise click.exceptions.Exit(1)
             elif success:
-                console.print("\n[green]✓ Update completed successfully![/green]")
+                success_color = theme_manager.get_color("success")
                 console.print(
-                    f"[cyan]Restart your terminal or run 'flow --version' to verify[/cyan]"
+                    f"\n[{success_color}]✓ Update completed successfully![/{success_color}]"
+                )
+                console.print(
+                    "[accent]Restart your terminal or run 'flow --version' to verify[/accent]"
                 )
                 if backup_file:
                     console.print(f"[dim]To rollback: flow update --rollback {backup_file}[/dim]")
@@ -437,13 +516,13 @@ class UpdateCommand(BaseCommand):
                 console.print("\n[red]✗ Update failed[/red]")
                 console.print("[yellow]Try running the update command manually:[/yellow]")
                 env_info = checker.detect_environment()
-                console.print(f"[cyan]{env_info['update_command']}[/cyan]")
+                console.print(f"[accent]{env_info['update_command']}[/accent]")
                 raise click.exceptions.Exit(1)
 
         return update
 
     def _display_version_info(
-        self, checker: UpdateChecker, update_available: bool, latest_version: Optional[str]
+        self, checker: UpdateChecker, update_available: bool, latest_version: str | None
     ) -> None:
         """Display version information in a nice format."""
 
@@ -483,3 +562,49 @@ Latest:  {latest_version or "Unknown"}
 
 # Export command instance
 command = UpdateCommand()
+
+
+def _parse_version(version_str: str | None):
+    """Parse version string into a tuple for safe comparison without packaging.
+
+    Handles semantic versions like '1.2.3', optionally with pre-release/build
+    metadata. Non-numeric parts are handled so that stable releases sort after
+    pre-releases (e.g., 1.0.0 > 1.0.0rc1).
+    """
+    if not version_str:
+        return (0, 0, 0, 1, ())
+
+    # Extract core numeric parts and pre-release tag
+    match = re.match(r"^(\d+)\.(\d+)(?:\.(\d+))?(.*)$", version_str)
+    if not match:
+        # Fallback: try to parse any digits we see
+        digits = [int(x) for x in re.findall(r"\d+", version_str)[:3]]
+        while len(digits) < 3:
+            digits.append(0)
+        # Treat unknown suffix as pre-release to keep it below stable
+        return (digits[0], digits[1], digits[2], 0, (version_str,))
+
+    major = int(match.group(1))
+    minor = int(match.group(2))
+    patch = int(match.group(3) or 0)
+    suffix = match.group(4) or ""
+
+    # Stable releases sort after pre-releases: use flag 1 for stable, 0 for pre
+    is_stable = 1 if suffix in ("", ".post", "+") else 0
+
+    # Normalize well-known pre-release tags so they sort correctly
+    # rc > beta > alpha
+    if "rc" in suffix:
+        pre_rank = 2
+    elif "b" in suffix or "beta" in suffix:
+        pre_rank = 1
+    elif "a" in suffix or "alpha" in suffix:
+        pre_rank = 0
+    else:
+        pre_rank = -1  # unknown; keep lowest
+
+    # Extract any trailing number in the suffix, e.g., rc1 -> 1
+    pre_num_match = re.search(r"(\d+)", suffix)
+    pre_num = int(pre_num_match.group(1)) if pre_num_match else 0
+
+    return (major, minor, patch, is_stable, (pre_rank, pre_num))
