@@ -1,6 +1,11 @@
-"""Shared utilities for CLI commands."""
+"""Shared utilities for CLI commands.
+
+This module centralizes small helpers used across multiple CLI commands.
+"""
 
 import time
+import os
+import sys
 from typing import Any
 
 from flow import Flow
@@ -271,3 +276,53 @@ def wait_for_task(
                         return status
 
                     time.sleep(2)
+
+
+def maybe_show_auto_status(*, focus: str | None = None, reason: str | None = None, show_all: bool | None = None, limit: int = 10) -> None:
+    """Optionally show a compact status table after a state-changing command.
+
+    Behavior:
+    - Enabled by default; disable with env `FLOW_AUTO_STATUS=0`.
+    - Suppressed when stdout is not a TTY (unless `FLOW_AUTO_STATUS=1` explicitly).
+    - Shows active tasks by default, limited to a small number to avoid noise.
+
+    Args:
+        focus: Optional task identifier to mention in a heading.
+        reason: Optional reason label to show in a dim header.
+        show_all: If True, show recent tasks; default is active-only.
+        limit: Maximum number of tasks to display (default: 10).
+    """
+    try:
+        pref = (os.environ.get("FLOW_AUTO_STATUS", "").strip().lower())
+        if pref in {"0", "false", "no", "off"}:
+            return
+        # If not an interactive terminal and not explicitly opted in, skip
+        if not sys.stdout.isatty() and pref not in {"1", "true", "yes", "on"}:
+            return
+
+        # Import lazily to avoid heavyweight imports during CLI bootstrap
+        from flow.cli.utils.task_presenter import DisplayOptions, TaskPresenter  # type: ignore
+
+        opts = DisplayOptions(
+            show_all=bool(show_all) if show_all is not None else False,
+            status_filter=None,
+            limit=max(1, int(limit or 10)),
+            show_details=False,
+            json_output=False,
+        )
+
+        header_bits: list[str] = []
+        if reason:
+            header_bits.append(reason)
+        header_bits.append("status")
+        if focus:
+            header_bits.append(f"for {focus}")
+        header_text = " ".join(header_bits).strip()
+        if header_text:
+            console.print(f"[dim]— {header_text} —[/dim]")
+
+        presenter = TaskPresenter(console)
+        presenter.present_task_list(opts)
+    except Exception:
+        # Never fail a primary command due to status rendering
+        return
