@@ -70,6 +70,7 @@ Note:
 """
 
 import click
+from datetime import datetime
 
 from flow import Flow
 from flow.cli.commands.base import BaseCommand, console
@@ -202,13 +203,24 @@ class VolumesCommand(BaseCommand):
                 with AnimatedEllipsisProgress(console, "Fetching volumes") as progress:
                     volumes = flow_client.list_volumes()
 
+                # Sort by creation time (newest first) for consistent, useful ordering
+                try:
+                    volumes = sorted(
+                        volumes,
+                        key=lambda v: getattr(v, "created_at", None) or datetime.min,
+                        reverse=True,
+                    )
+                except Exception:
+                    # If sorting fails for any reason, fall back to provider order
+                    pass
+
                 if not volumes:
                     console.print("\nNo volumes found.")
                     self.show_next_actions(
                         [
-                            "Create a new volume: [accent]flow volumes create --size 100[/accent]",
-                            "Create a named volume: [accent]flow volumes create --size 50 --name training-data[/accent]",
-                            "Create file storage: [accent]flow volumes create --size 200 --interface file[/accent]",
+                            "Create a new volume: [accent]flow volumes create --size 100[/accent] [dim]# size in GB[/dim]",
+                            "Create a named volume: [accent]flow volumes create --size 50 --name training-data[/accent] [dim]# size in GB[/dim]",
+                            "Create file storage: [accent]flow volumes create --size 200 --interface file[/accent] [dim]# size in GB[/dim]",
                         ]
                     )
                     return
@@ -248,8 +260,8 @@ class VolumesCommand(BaseCommand):
                 )
                 add_centered_column(
                     table,
-                    "Size\n(GB)",  # Split header to save width
-                    width=8,  # Fixed for "10000" max
+                    "Size (GB)",
+                    width=10,  # Enough for header and values like "10000"
                 )
 
                 # Show additional columns based on terminal width
@@ -359,11 +371,11 @@ class VolumesCommand(BaseCommand):
 
                 # Show next actions with index support
                 volume_count = min(len(volumes), 5)  # Show up to 5 index examples
-                index_help = f":1-{volume_count}" if volume_count > 1 else ":1"
+                index_help = f"1-{volume_count}" if volume_count > 1 else "1"
 
                 self.show_next_actions(
                     [
-                        "Create a new volume: [accent]flow volumes create --size 100[/accent]",
+                        "Create a new volume: [accent]flow volumes create --size 100[/accent] [dim]# size in GB[/dim]",
                         f"Delete a volume: [accent]flow volumes delete <volume-name-or-id>[/accent] or [accent]flow volumes delete {index_help}[/accent]",
                     ]
                 )
@@ -408,6 +420,7 @@ class VolumesCommand(BaseCommand):
                 self.show_next_actions(
                     [
                         "List all volumes: [accent]flow volumes list[/accent]",
+                        "All sizes are specified in GB (gigabytes)",
                         "Use in task config: Add to YAML under storage.volumes",
                         "Submit task with volume: [accent]flow run task.yaml[/accent]",
                     ]
@@ -419,6 +432,13 @@ class VolumesCommand(BaseCommand):
                         invalidate_cache_for_current_context,
                         refresh_volumes_cache,
                     )
+                    # Also clear index cache so :N mappings refresh next list
+                    try:
+                        from flow.cli.utils.volume_index_cache import VolumeIndexCache
+
+                        VolumeIndexCache().clear()
+                    except Exception:
+                        pass
 
                     invalidate_cache_for_current_context(
                         ["volumes_list"]
@@ -471,7 +491,7 @@ class VolumesCommand(BaseCommand):
             Examples:
                 flow volumes delete vol_abc123def456
                 flow volumes delete training-data
-                flow volumes delete :1
+                flow volumes delete 1
                 flow volumes delete all
                 flow volumes delete training --yes
             """
@@ -558,6 +578,13 @@ class VolumesCommand(BaseCommand):
                         invalidate_cache_for_current_context,
                         refresh_volumes_cache,
                     )
+                    # Also clear index cache so :N mappings refresh next list
+                    try:
+                        from flow.cli.utils.volume_index_cache import VolumeIndexCache
+
+                        VolumeIndexCache().clear()
+                    except Exception:
+                        pass
 
                     invalidate_cache_for_current_context(
                         ["volumes_list"]
@@ -642,6 +669,13 @@ class VolumesCommand(BaseCommand):
                         invalidate_cache_for_current_context,
                         refresh_volumes_cache,
                     )
+                    # Also clear index cache so :N mappings refresh next list
+                    try:
+                        from flow.cli.utils.volume_index_cache import VolumeIndexCache
+
+                        VolumeIndexCache().clear()
+                    except Exception:
+                        pass
 
                     invalidate_cache_for_current_context(
                         ["volumes_list"]
