@@ -326,7 +326,12 @@ class GPUFormatter:
 
         # If we couldn't parse a model, use truncated instance type
         if not model:
-            model = raw.upper()[:6]
+            # Heuristic: if looks like a bare series (e.g., a100), upcase the letter and keep 3 digits
+            m = re.match(r"\s*([ahvb])\s*(\d{2,3})\b", lower)
+            if m:
+                model = f"{m.group(1).upper()}{m.group(2)}"
+            else:
+                model = raw.upper()[:6]
 
         # Detect NVL topology from anywhere in type (e.g., gb200nvl72)
         # Detect NVL topology from anywhere in type (e.g., gb200nvl72)
@@ -351,7 +356,16 @@ class GPUFormatter:
             if gpus_per_node > 1:
                 parts.append(f"{gpus_per_node}×{model}")
             else:
-                parts.append(model)
+                # Ensure bare models like A100, H100 render fully, not A10
+                # If model looks like a letter followed by 2-3 digits and raw contains that series,
+                # prefer the normalized GPU type from format_gpu_type to avoid accidental truncation.
+                try:
+                    if re.match(r"^[AHVB]\d{2,3}$", model) and model[0].lower() + model[1:] in lower:
+                        parts.append(GPUFormatter.format_gpu_type(raw))
+                    else:
+                        parts.append(model)
+                except Exception:
+                    parts.append(model)
 
             if memory:
                 parts.append(f"·{memory}")
