@@ -94,7 +94,7 @@ def _context_prefix() -> str:
 
     Avoids cross-project leaks in long-lived shells and multiple accounts.
     """
-    # Memoize once per process for minimal overhead
+    # Memoize per process, but allow explicit reset via reset_context()
     global _CTX_PREFIX  # noqa: PLW0603
     try:
         prefix = globals().get("_CTX_PREFIX")
@@ -116,6 +116,36 @@ def _context_prefix() -> str:
         return "unknown|-"
 
 
+def reset_context() -> None:
+    """Reset the cached context prefix and clear current-context cache.
+
+    Call this when the provider base URL or project changes during a long-lived
+    process. It clears the in-memory cache for the old namespace and forces the
+    next access to compute a fresh namespace derived from the current config.
+    """
+    try:
+        # Snapshot known keys to clear for the current (old) context
+        keys_to_clear = [
+            "tasks_running",
+            "tasks_pending",
+            "tasks_all",
+            "instance_catalog",
+            "volumes_list",
+            "ssh_keys",
+            "projects",
+            "me",
+            "reservations",
+        ]
+        invalidate_cache_for_current_context(keys_to_clear)
+    except Exception:
+        pass
+    # Drop memoized prefix so next call recomputes
+    try:
+        globals().pop("_CTX_PREFIX", None)
+    except Exception:
+        pass
+
+
 def _ns(key: str) -> str:
     return f"{_context_prefix()}::{key}"
 
@@ -216,6 +246,26 @@ def invalidate_cache_for_current_context(keys: Iterable[str]) -> None:
         pass
 
 
+def invalidate_snapshots(keys: Iterable[str]) -> None:
+    """Remove on-disk snapshots for the given cache keys in this context.
+
+    This prevents a subsequent CLI invocation from rehydrating stale task lists
+    from disk (e.g., right after a cancellation), ensuring the next command
+    performs a live fetch instead of showing outdated results.
+    """
+    try:
+        for k in keys:
+            try:
+                path = _snapshot_path(k)
+                if path.exists():
+                    path.unlink(missing_ok=True)  # type: ignore[arg-type]
+            except Exception:
+                # Best-effort cleanup; ignore any filesystem errors
+                continue
+    except Exception:
+        pass
+
+
 def _should_enable() -> bool:
     # Default enabled; explicitly disable with FLOW_PREFETCH=0
     return os.environ.get("FLOW_PREFETCH", "1") != "0"
