@@ -11,11 +11,13 @@ from flow.cli.utils.task_index_cache import TaskIndexCache
 def parse_selection_to_task_ids(expr: str) -> tuple[list[str] | None, str | None]:
     """Parse an index/range expression to concrete task IDs via cache.
 
-    Accepts optional leading colon, e.g. ":1-3,5" or "2".
+    Accepts bare numbers and ranges (preferred), e.g. "1-3,5", and the legacy
+    leading-colon form, e.g. ":1-3,5".
 
     Returns (task_ids, error_msg). On error, (None, message).
     """
     expression = expr.strip()
+    # Accept digits, commas, ranges, with optional legacy leading colon
     if not re.fullmatch(r":?[0-9,\-\s]+", expression):
         return None, None  # Not a selection grammar; caller may treat as name/ID
 
