@@ -496,6 +496,10 @@ complete -c flow -f -a "(_flow_completion)"'''
 def complete_task_ids(ctx, args, incomplete):
     """Complete task IDs for commands that operate on tasks."""
     try:
+        # Only compute completions during an actual shell completion session.
+        # Click sets _FLOW_COMPLETE for completion subprocesses; avoid API calls otherwise.
+        if os.environ.get("_FLOW_COMPLETE") is None:
+            return []
         # Only complete if we have credentials
         validator = ConfigValidator()
         if not validator.validate_credentials():
