@@ -13,10 +13,10 @@ class SSHKeyCache:
     """Manages cached SSH key resolutions.
 
     Stores mappings from task IDs to resolved SSH key paths, avoiding
-    expensive repeated lookups. Cache entries expire after 30 minutes.
+    expensive repeated lookups. Cache entries expire after 5 minutes.
     """
 
-    CACHE_TTL_SECONDS = 1800  # 30 minutes
+    CACHE_TTL_SECONDS = 300  # 5 minutes
 
     def __init__(self, cache_dir: Path | None = None):
         """Initialize cache with optional custom directory.
@@ -27,12 +27,21 @@ class SSHKeyCache:
         self.cache_dir = cache_dir or Path.home() / ".flow"
         self.cache_file = self.cache_dir / "ssh_keys.json"
 
-    def save_key_path(self, task_id: str, key_path: str) -> None:
+    def save_key_path(
+        self,
+        task_id: str,
+        key_path: str,
+        *,
+        platform_key_ids: list[str] | None = None,
+        public_key_fingerprint: str | None = None,
+    ) -> None:
         """Cache a resolved SSH key path.
 
         Args:
             task_id: Task ID
             key_path: Resolved SSH private key path
+            platform_key_ids: Platform SSH key IDs associated with the task (for validation)
+            public_key_fingerprint: Optional normalized public key fingerprint
         """
         # Create directory if needed
         self.cache_dir.mkdir(parents=True, exist_ok=True)
@@ -41,7 +50,12 @@ class SSHKeyCache:
         cache_data = self._load_cache() or {"keys": {}}
 
         # Update with new key
-        cache_data["keys"][task_id] = {"path": key_path, "timestamp": time.time()}
+        entry = {"path": key_path, "timestamp": time.time()}
+        if platform_key_ids:
+            entry["platform_keys"] = platform_key_ids
+        if public_key_fingerprint:
+            entry["fingerprint"] = public_key_fingerprint
+        cache_data["keys"][task_id] = entry
 
         # Clean expired entries
         self._clean_expired(cache_data)
@@ -51,11 +65,19 @@ class SSHKeyCache:
         temp_file.write_text(json.dumps(cache_data, indent=2))
         temp_file.replace(self.cache_file)
 
-    def get_key_path(self, task_id: str) -> str | None:
+    def get_key_path(
+        self,
+        task_id: str,
+        *,
+        validate_with_platform_keys: list[str] | None = None,
+        expected_fingerprint: str | None = None,
+    ) -> str | None:
         """Get cached SSH key path if available.
 
         Args:
             task_id: Task ID to look up
+            validate_with_platform_keys: If provided, ensure cached entry matches these IDs
+            expected_fingerprint: If provided, ensure cached entry matches this fingerprint
 
         Returns:
             SSH key path or None if not cached/expired
@@ -73,6 +95,18 @@ class SSHKeyCache:
         if age > self.CACHE_TTL_SECONDS:
             return None
 
+        # Optional validation against platform keys
+        if validate_with_platform_keys is not None:
+            cached_platform_keys = key_info.get("platform_keys") or []
+            if cached_platform_keys and not any(k in cached_platform_keys for k in validate_with_platform_keys):
+                return None
+
+        # Optional validation against fingerprint
+        if expected_fingerprint is not None:
+            cached_fp = key_info.get("fingerprint")
+            if cached_fp and cached_fp != expected_fingerprint:
+                return None
+
         key_path = key_info.get("path")
         if key_path and Path(key_path).exists():
             return key_path
