@@ -18,6 +18,10 @@ from flow.cli.utils.task_fetcher import TaskFetcher
 from flow.cli.utils.task_index_cache import TaskIndexCache
 from flow.cli.utils.theme_manager import theme_manager
 from flow.cli.utils.time_formatter import TimeFormatter
+from flow.cli.utils.next_steps import (
+    build_status_recommendations,
+    render_next_steps_panel,
+)
 
 
 @dataclass
@@ -39,9 +43,16 @@ class StatusPresenter:
 
     def present(self, options: StatusDisplayOptions, tasks: list[Task] | None = None) -> None:
         if tasks is None:
-            tasks = self.fetcher.fetch_for_display(
-                show_all=options.show_all, status_filter=None, limit=options.limit
-            )
+            # Fast path: perform a single provider call to detect empty state
+            try:
+                tasks = self.flow.list_tasks(limit=options.limit)
+            except Exception:
+                # Fall back to fetcher on provider issues
+                tasks = None
+            if tasks is None:
+                tasks = self.fetcher.fetch_for_display(
+                    show_all=options.show_all, status_filter=None, limit=options.limit
+                )
         if not tasks:
             self.console.print("[dim]No tasks found[/dim]")
             return
@@ -138,8 +149,9 @@ class StatusPresenter:
         if not options.show_all:
             self.console.print("[dim]Showing active tasks only. Use --all to see all tasks.[/dim]")
         self.console.print(
-            "[dim]Tip: Index shortcuts (:1, 2, 1-3) are valid for 30 minutes after this view.[/dim]"
+            "[dim]Tip: Index shortcuts (1, 1-3; ':1' also works) are valid for 5 minutes after this view.[/dim]"
         )
+        self.console.print("[dim]Re-run 'flow status' to refresh indices.[/dim]")
 
         # Save indices in the order displayed so shortcuts match UI numbering
         # Be resilient when tasks are mocks (tests) and may not be JSON serializable
@@ -152,32 +164,28 @@ class StatusPresenter:
 
         count = min(len(displayed_tasks), options.limit)
         if count >= 7:
-            multi_example = ":1-3,5,7"
-            range_example = ":1-3"
+            multi_example = "1-3,5,7"
+            range_example = "1-3"
         elif count >= 5:
-            multi_example = ":1-3,5"
-            range_example = ":1-3"
+            multi_example = "1-3,5"
+            range_example = "1-3"
         elif count >= 3:
-            multi_example = ":1-3"
-            range_example = ":1-3"
+            multi_example = "1-3"
+            range_example = "1-3"
         elif count == 2:
-            multi_example = ":1-2"
-            range_example = ":1-2"
+            multi_example = "1-2"
+            range_example = "1-2"
         else:
-            multi_example = ":1"
-            range_example = ":1"
+            multi_example = "1"
+            range_example = "1"
 
-        steps = [
-            "\n[bold]Next steps:[/bold]",
-            "  • SSH into running task:",
-            "    [accent]flow ssh <task-name>[/accent]",
-            "    [accent]flow ssh :1[/accent]",
-            "  • View logs for a task:",
-            "    [accent]flow logs <task-name>[/accent]",
-            "    [accent]flow logs :1[/accent]",
-            "  • Cancel tasks by index or range:",
-            "    [accent]flow cancel :1-3,5[/accent]",
-            "  • Submit a new task:",
-            "    [accent]flow run task.yaml[/accent]",
-        ]
-        self.console.print("\n" + "\n".join(steps))
+        # Dynamic, context-aware next steps
+        index_example_single = "1"
+        recommendations = build_status_recommendations(
+            displayed_tasks,
+            max_count=3,
+            index_example_single=index_example_single,
+            index_example_multi=multi_example,
+        )
+        if recommendations:
+            render_next_steps_panel(self.console, recommendations)
