@@ -219,7 +219,12 @@ class StepTimeline:
             # Duration display
             dur = ""
             if step.started_mono and step.finished_mono:
-                dur_secs = int(step.finished_mono - step.started_mono)
+                # Prefer showing wall-clock duration inclusive of any seeded baseline
+                # so that resume scenarios (e.g., provisioning already in progress)
+                # reflect total wait rather than just the local delta.
+                baseline = step.baseline_elapsed_seconds or 0
+                local_delta = int(step.finished_mono - step.started_mono)
+                dur_secs = baseline + local_delta if baseline > 0 else local_delta
                 dur = f" ({dur_secs}s)"
             note = f" – {step.note}" if step.note else ""
             # Compose styled segments instead of markup so colors render in Live
