@@ -322,49 +322,17 @@ class TaskFetcher:
                 active_tasks.sort(key=lambda t: t.created_at, reverse=True)
                 return active_tasks[:limit]
 
-            # No active tasks found - batch all three calls concurrently and pick best slice
+            # No active tasks found - perform a single provider call and return empty if also empty
             try:
-                with ThreadPoolExecutor(max_workers=3) as ex:
-                    futures = [
-                        ex.submit(self.flow_client.list_tasks, status=TaskStatus.RUNNING, limit=min(100, limit)),
-                        ex.submit(self.flow_client.list_tasks, status=TaskStatus.PENDING, limit=min(100, limit)),
-                        ex.submit(self.flow_client.list_tasks, status=None, limit=limit),
-                    ]
-                    results: list[Task] = []  # type: ignore[name-defined]
-                    for f in as_completed(futures, timeout=2.0):
-                        try:
-                            r = f.result() or []
-                            results.extend(r)
-                        except Exception:
-                            pass
-                    # Prefer active tasks if any present
-                    active = [
-                        t
-                        for t in results
-                        if getattr(getattr(t, "status", None), "value", None) in {"running", "pending"}
-                    ]
-                    if active:
-                        # Deduplicate and sort
-                        seen: dict[str, Task] = {}
-                        for t in active:
-                            tid = getattr(t, "task_id", None)
-                            if tid and tid not in seen:
-                                seen[tid] = t
-                        active = sorted(seen.values(), key=lambda t: getattr(t, "created_at", 0), reverse=True)
-                        return active[:limit]
-                    # Else, return most recent general list
-                    general = [
-                        t
-                        for t in results
-                        if getattr(getattr(t, "status", None), "value", None) not in {"running", "pending"}
-                    ]
-                    if general:
-                        general = sorted(general, key=lambda t: getattr(t, "created_at", 0), reverse=True)
-                        return general[:limit]
+                general = self.flow_client.list_tasks(limit=limit)
+                if not general:
+                    return []
+                # Else, sort and return most recent general list
+                general = sorted(general, key=lambda t: getattr(t, "created_at", 0), reverse=True)
+                return general[:limit]
             except Exception:
-                pass
-            # Fallback to prior behavior
-            return self.fetch_all_tasks(limit=limit, prioritize_active=True, status_filter=None)
+                # Fallback to prior behavior
+                return self.fetch_all_tasks(limit=limit, prioritize_active=True, status_filter=None)
         else:
             # Specific status filter or --all flag
             return self.fetch_all_tasks(
