@@ -185,10 +185,11 @@ class TaskFormatter:
         if instance_status == "STATUS_SCHEDULED":
             return "pending"
 
-        # Treat RUNNING without SSH as "starting" only for young instances
-        if status_value == "running" and not getattr(task, "ssh_host", None):
+        # Treat RUNNING tasks as "starting" during early provisioning
+        # - Without SSH: within ~15 minutes of instance creation
+        # - With SSH already available: within a shorter window (~10 minutes)
+        if status_value == "running":
             try:
-                # Consider the instance young if < 15 minutes old
                 age_s = getattr(task, "instance_age_seconds", None)
                 if callable(age_s):
                     age_s = age_s()
@@ -197,8 +198,21 @@ class TaskFormatter:
                     created = getattr(task, "created_at", None)
                     if created:
                         age_s = (datetime.now(timezone.utc) - created).total_seconds()
-                if age_s is None or age_s < 15 * 60:
-                    return "starting"
+
+                has_ssh = bool(getattr(task, "ssh_host", None))
+
+                # Thresholds chosen to align UX across list/detail views and
+                # with provisioning messages without overextending the "starting" label
+                without_ssh_threshold_s = 15 * 60
+                with_ssh_threshold_s = 10 * 60
+
+                if not has_ssh:
+                    if age_s is None or age_s < without_ssh_threshold_s:
+                        return "starting"
+                else:
+                    # Even if SSH is up, treat very young instances as starting for consistency
+                    if age_s is None or age_s < with_ssh_threshold_s:
+                        return "starting"
             except Exception:
                 # Be conservative if we cannot determine age
                 return "starting"
