@@ -1,6 +1,6 @@
 """Task index cache for quick task references.
 
-Provides ephemeral index-based task references (e.g., ":1", ":2") based on the
+Provides ephemeral index-based task references (e.g., "1", "2"; legacy ":1", ":2") based on the
 last shown task list. Also serves as the backing data for list/range selections
 like "1,2-3,9" used by CLI commands via `selection.py` and
 `selection_helpers.py`. Behavior is explicit and time-bounded to prevent stale
@@ -20,15 +20,28 @@ class TaskIndexCache:
     Stores a 1-based index -> task_id map for the last displayed task list,
     plus lightweight task details for fast UX. Used in two ways:
 
-    - Single-index resolution via `resolve_index(":N")`
+    - Single-index resolution via `resolve_index(":N")` (legacy input accepted; callers may pass bare "N")
     - Range/list selections (e.g., "1-3,5,7") by callers that parse the
       expression (see `selection.py`) and then map indices using
       `get_indices_map()`
 
-    Indices expire after 30 minutes to prevent stale references.
+    Indices expire after 5 minutes to prevent stale references.
     """
 
-    CACHE_TTL_SECONDS = 1800  # 30 minutes
+    CACHE_TTL_SECONDS = 300  # 5 minutes
+
+    def _current_context(self) -> str | None:
+        """Return a context string to scope cache entries.
+
+        Best-effort: use the prefetch context when available; otherwise None.
+        """
+        try:
+            # Use the same context prefix logic as prefetch to avoid cross-project leaks
+            from flow.cli.utils.prefetch import _context_prefix  # type: ignore
+
+            return _context_prefix()
+        except Exception:
+            return None
 
     def __init__(self, cache_dir: Path | None = None):
         """Initialize cache with optional custom directory.
@@ -98,6 +111,8 @@ class TaskIndexCache:
             "task_details": task_details,
             "timestamp": time.time(),
             "task_count": len(tasks),
+            # Scope on-disk indices to current provider/project context when known
+            "context": self._current_context(),
         }
 
         # Atomic write
@@ -108,9 +123,9 @@ class TaskIndexCache:
     def resolve_index(self, index_str: str) -> tuple[str | None, str | None]:
         """Resolve a single index reference to a task ID.
 
-        Accepts only the `:N` form. For lists/ranges (e.g., "1-3,5"), use the
-        selection utilities (`selection.py` / `selection_helpers.py`) to parse
-        the expression and then map via `get_indices_map()`.
+        Accepts legacy `:N` and also bare `N`. For lists/ranges (e.g., "1-3,5"),
+        use the selection utilities (`selection.py` / `selection_helpers.py`) to
+        parse the expression and then map via `get_indices_map()`.
 
         Args:
             index_str: Index string (e.g., ":1", ":2")
@@ -119,11 +134,13 @@ class TaskIndexCache:
             Tuple of (task_id if found, error message if any)
         """
         # Parse index
-        if not index_str.startswith(":"):
-            return None, None  # Not an index reference
+        if index_str.startswith(":"):
+            raw = index_str[1:]
+        else:
+            raw = index_str
 
         try:
-            index = int(index_str[1:])
+            index = int(raw)
         except ValueError:
             return None, f"Invalid index format: {index_str}"
 
@@ -174,7 +191,16 @@ class TaskIndexCache:
             return None
 
         try:
-            return json.loads(self.cache_file.read_text())
+            data = json.loads(self.cache_file.read_text())
+            # If cache was saved under a different context, treat as missing
+            try:
+                saved_ctx = data.get("context")
+                curr_ctx = self._current_context()
+                if saved_ctx is not None and curr_ctx is not None and saved_ctx != curr_ctx:
+                    return None
+            except Exception:
+                pass
+            return data
         except (json.JSONDecodeError, KeyError):
             # Invalid cache file
             return None
