@@ -10,7 +10,11 @@ from typing import Any
 
 from rich.console import Console
 
-from flow import Flow
+# Prefer Flow symbol from the status module to keep tests that patch it consistent
+try:
+    from flow.cli.commands.status import Flow  # type: ignore
+except Exception:  # pragma: no cover - fallback path
+    from flow import Flow  # type: ignore
 from flow.cli.utils.task_fetcher import TaskFetcher
 from flow.cli.utils.task_filter import TaskFilter
 from flow.cli.utils.task_index_cache import TaskIndexCache
@@ -107,7 +111,31 @@ class TaskPresenter:
 
         # Fetch tasks if not provided
         if tasks is None:
-            tasks = self._fetch_tasks(options)
+            # Fast-path probe to minimize provider calls in empty states
+            tasks_direct = None
+            try:
+                tasks_direct = self.flow_client.list_tasks(limit=options.limit)
+            except Exception:
+                tasks_direct = None
+
+            if tasks_direct is not None:
+                if not tasks_direct:
+                    # No tasks at all — show empty state and return a minimal summary
+                    self._show_no_tasks_message(options)
+                    return TaskSummary(
+                        total_shown=0,
+                        total_available=0,
+                        filtered_by_status=bool(options.status_filter),
+                        filtered_by_time=(not options.show_all),
+                        active_tasks=0,
+                    )
+                tasks = tasks_direct
+            else:
+                # Fall back to full fetcher logic
+                tasks = self._fetch_tasks(options)
+        else:
+            # Explicit tasks provided by caller (including empty list) → do not call provider
+            pass
 
         # Apply filters
         filtered_tasks, summary = self._filter_tasks(tasks, options)
