@@ -16,6 +16,7 @@ from flow.cli.utils.task_formatter import TaskFormatter
 from flow.cli.utils.terminal_adapter import TerminalAdapter
 from flow.cli.utils.theme_manager import theme_manager
 from flow.cli.utils.time_formatter import TimeFormatter
+from flow.cli.utils.owner_resolver import OwnerResolver
 
 
 class TaskTableRenderer:
@@ -44,9 +45,14 @@ class TaskTableRenderer:
         from flow.cli.utils.status_table_renderer import StatusTableRenderer as CoreStatusTable
 
         renderer = CoreStatusTable(self.console)
+        # Resolve current user so the Owner column shows a friendly label consistently
+        try:
+            me = OwnerResolver().get_me()
+        except Exception:
+            me = None
         panel = renderer.render(
             tasks,
-            me=None,
+            me=me,
             title=(
                 title or f"Tasks (showing up to {limit}{', last 24 hours' if not show_all else ''})"
             ),
@@ -385,12 +391,29 @@ class TaskDetailRenderer:
         if task.region:
             lines.append(f"[bold]Region:[/bold] {task.region}")
 
+         # SSH keys used (when available)
+        try:
+            cfg = getattr(task, "config", None)
+            ssh_keys_cfg = list(getattr(cfg, "ssh_keys", []) or []) if cfg is not None else []
+            if ssh_keys_cfg:
+                # Show up to 3 keys inline; indicate more when applicable
+                shown = ssh_keys_cfg[:3]
+                extra = f" (+{len(ssh_keys_cfg) - 3} more)" if len(ssh_keys_cfg) > 3 else ""
+                keys_str = ", ".join(shown)
+                lines.append(f"[bold]SSH Keys:[/bold] {keys_str}{extra}")
+        except Exception:
+            pass
+
         # Connection info (show IP/port when available)
-        if getattr(task, "ssh_host", None):
+        try:
+            host = getattr(task, "public_ip", None) or getattr(task, "ssh_host", None)
+        except Exception:
+            host = getattr(task, "ssh_host", None)
+        if host:
             if getattr(task, "ssh_port", None):
-                lines.append(f"[bold]IP:[/bold] {task.ssh_host}:{task.ssh_port}")
+                lines.append(f"[bold]IP:[/bold] {host}:{task.ssh_port}")
             else:
-                lines.append(f"[bold]IP:[/bold] {task.ssh_host}")
+                lines.append(f"[bold]IP:[/bold] {host}")
 
         # Endpoints and ports (best-effort)
         try:
@@ -430,7 +453,10 @@ class TaskDetailRenderer:
                     lines.append("[bold]Ports:[/bold] " + ", ".join(str(p) for p in ports_clean))
 
                     # If IP is known, show public URLs and an SSH tunnel example
-                    host = getattr(task, "ssh_host", None)
+                    try:
+                        host = getattr(task, "public_ip", None) or getattr(task, "ssh_host", None)
+                    except Exception:
+                        host = getattr(task, "ssh_host", None)
                     if host:
                         # Public URLs
                         url_items = [f"http://{host}:{p}" for p in ports_clean]
@@ -523,7 +549,8 @@ class TaskDetailRenderer:
         panel_content = "\n".join(lines)
         title = f"Task: {task.name or task.task_id}"
 
-        panel = Panel(
+        # Keep details compact and avoid stretching to full terminal width
+        panel = Panel.fit(
             panel_content,
             title=title,
             title_align="left",
