@@ -34,7 +34,7 @@ def resolve_task_identifier(
 
     Resolution order:
     0. Special alias ':dev' (current user's dev VM)
-    1. Index reference (e.g., :1, :2)
+    1. Index reference (e.g., 1, 2 or legacy ':1', ':2')
     2. Direct get_task() lookup (for exact task IDs)
     3. Exact task_id match from list
     4. Exact name match
@@ -61,7 +61,7 @@ def resolve_task_identifier(
             return None, "No dev VM found for this user. Create one with: flow dev"
         return vm, None
 
-    # Check for index reference first (e.g., :1, :2) or bare single index (e.g., 1)
+    # Check for index reference first (e.g., 1, 2 or legacy :1, :2)
     if identifier.startswith(":"):
         cache = TaskIndexCache()
         task_id, error = cache.resolve_index(identifier)
@@ -71,8 +71,8 @@ def resolve_task_identifier(
                 f"No task found for index reference '{identifier}'.",
                 "",
                 "Tips:",
-                "  • Run 'flow status' to refresh the index cache (now lasts 30 minutes).",
-                "  • Use single index like ':1' or bare '1' after 'flow status'.",
+                "  • Run 'flow status' to refresh the index cache (valid for 5 minutes).",
+                "  • Use single index like '1' (preferred) or legacy ':1' after 'flow status'.",
                 "  • For names or IDs, use the full task name or task ID.",
                 "  • Use ':dev' to target your dev VM directly.",
             ]
@@ -81,7 +81,7 @@ def resolve_task_identifier(
             # Resolve the cached task ID
             identifier = task_id
     else:
-        # Accept bare single-index form for consistency with tips (e.g., "2")
+        # Accept bare single-index form (preferred) for consistency (e.g., "2")
         import re as _re
 
         if _re.fullmatch(r"\d+", identifier):
@@ -137,15 +137,15 @@ def resolve_task_identifier(
     # Build multi-line, readable guidance
     lines = [f"No task found matching '{identifier}'.", "", "Suggestions:"]
 
-    # Index-looking input (digits or digits/ranges with optional colon)
+    # Index-looking input (digits or digits/ranges with optional legacy colon)
     import re
 
     looks_like_index = bool(re.fullmatch(r":?[0-9,\-\s]+", identifier))
     if looks_like_index:
         lines.extend(
             [
-                "  • Run 'flow status' to refresh the index cache (valid for 30 minutes).",
-                "  • Then use ':1' or '1' to reference a specific row.",
+                "  • Run 'flow status' to refresh the index cache (valid for 5 minutes).",
+                "  • Then use '1' to reference a specific row (':1' also works for legacy).",
                 "  • Ranges like '1-3,5' are supported for commands that accept multi-select.",
             ]
         )
@@ -158,7 +158,7 @@ def resolve_task_identifier(
                     "  • Verify the task ID is correct.",
                 ]
             )
-        lines.append("  • Use 'flow status' to list tasks, then select by name, ID, or index (:1).")
+        lines.append("  • Use 'flow status' to list tasks, then select by name, ID, or index (1).")
 
     return None, "\n".join(lines)
 
