@@ -1,6 +1,6 @@
 """Volume index cache for quick volume references.
 
-Provides ephemeral index-based volume references (e.g., :1, :2) based on the
+Provides ephemeral index-based volume references (e.g., 1, 2; legacy :1, :2) based on the
 last shown volume list. Behavior is explicit and time-bounded to prevent stale
 references.
 """
@@ -22,6 +22,18 @@ class VolumeIndexCache:
 
     CACHE_TTL_SECONDS = 300  # 5 minutes
 
+    def _current_context(self) -> str | None:
+        """Return a context string to scope cache entries.
+
+        Best-effort: use the prefetch context when available; otherwise None.
+        """
+        try:
+            from flow.cli.utils.prefetch import _context_prefix  # type: ignore
+
+            return _context_prefix()
+        except Exception:
+            return None
+
     def __init__(self, cache_dir: Path | None = None):
         """Initialize cache with optional custom directory.
 
@@ -60,6 +72,8 @@ class VolumeIndexCache:
             "volume_details": volume_details,
             "timestamp": time.time(),
             "volume_count": len(volumes),
+            # Scope on-disk indices to current provider/project context when known
+            "context": self._current_context(),
         }
 
         # Atomic write
@@ -71,17 +85,19 @@ class VolumeIndexCache:
         """Resolve an index reference to a volume ID.
 
         Args:
-            index_str: Index string (e.g., ":1", ":2")
+            index_str: Index string (e.g., "1", ":1")
 
         Returns:
             Tuple of (volume_id if found, error message if any)
         """
         # Parse index
-        if not index_str.startswith(":"):
-            return None, None  # Not an index reference
+        if index_str.startswith(":"):
+            raw = index_str[1:]
+        else:
+            raw = index_str
 
         try:
-            index = int(index_str[1:])
+            index = int(raw)
         except ValueError:
             return None, f"Invalid index format: {index_str}"
 
@@ -116,7 +132,15 @@ class VolumeIndexCache:
             return None
 
         try:
-            return json.loads(self.cache_file.read_text())
+            data = json.loads(self.cache_file.read_text())
+            try:
+                saved_ctx = data.get("context")
+                curr_ctx = self._current_context()
+                if saved_ctx is not None and curr_ctx is not None and saved_ctx != curr_ctx:
+                    return None
+            except Exception:
+                pass
+            return data
         except (json.JSONDecodeError, KeyError):
             # Invalid cache file
             return None
