@@ -15,7 +15,7 @@ def resolve_volume_identifier(
     """Resolve a volume identifier (name or ID) to a Volume object.
 
     Resolution order:
-    1. Index reference (e.g., :1, :2)
+    1. Index reference (e.g., 1, 2, or legacy ":1", ":2")
     2. Exact volume ID match
     3. Exact name match
     4. Partial name match
@@ -29,7 +29,7 @@ def resolve_volume_identifier(
         - volume: The resolved Volume object if found
         - error_message: Error description if not found
     """
-    # Check for index reference first (e.g., :1, :2)
+    # Check for index reference first (e.g., 1, 2 or legacy :1, :2)
     if identifier.startswith(":"):
         cache = VolumeIndexCache()
         volume_id, error = cache.resolve_index(identifier)
@@ -38,6 +38,17 @@ def resolve_volume_identifier(
         if volume_id:
             # Resolve the cached volume ID
             identifier = volume_id
+    else:
+        # Accept bare single-index form for consistency with task indices (e.g., "2")
+        import re as _re
+
+        if _re.fullmatch(r"\d+", identifier):
+            cache = VolumeIndexCache()
+            volume_id, error = cache.resolve_index(f":{identifier}")
+            if error:
+                return None, error
+            if volume_id:
+                identifier = volume_id
 
     # Check if it's a volume ID via provider interface
     provider = flow_client.provider
