@@ -820,11 +820,14 @@ class GenericSetupWizard:
         self.console.print()
         panel_styles = get_panel_styles()
         try:
-            # Clamp panel width so it doesn't stretch excessively on very wide terminals
+            # Use a consistent panel width for visual coherence across screens.
+            # Clamp to terminal width to avoid overflow on very narrow terminals.
             from flow.cli.utils.terminal_adapter import TerminalAdapter as _TA
 
             term_w = _TA.get_terminal_width()
-            panel_w = min(term_w - 4, max(56, int(term_w * 0.6)))
+            desired_w = SPACING.get("panel_width", 60)
+            # Ensure at least 56 cols for the status table; never exceed terminal width minus padding.
+            panel_w = min(max(56, desired_w), max(40, term_w - 4))
         except Exception:
             panel_w = SPACING.get("panel_width", 60)
 
@@ -872,7 +875,8 @@ class GenericSetupWizard:
                 self.console.print(
                     f"{format_text('muted', 'About SSH access:')} "
                     f"{format_text('body', 'Your Default SSH Key lets you securely log into instances. ')}"
-                    f"{format_text('body', 'Choose an existing key in your Mithril account or select Auto‑generate to have a fresh key per instance (recommended).')}\n"
+                    f"{format_text('body', 'Choose an existing key or Generate on Mithril (recommended). Private keys are saved to ~/.flow/keys/.')}\n"
+                    f"{format_text('muted', 'More details: run')} [accent]flow init --verbose[/accent]  •  "
                     f"{format_text('muted', 'Manage keys:')} [link]{WebLinks.ssh_keys()}[/link]"
                 )
         except Exception:
@@ -933,40 +937,35 @@ class GenericSetupWizard:
                         display_value = "••••"
                     source_display = "detected"
 
-                # SSH key: treat _auto_ as configured; otherwise verify presence when possible
+                # SSH key: do not special-case deprecated _auto_; verify presence when possible
                 elif field.name == "default_ssh_key":
                     key_id = str(value)
-                    if key_id.strip() == "_auto_":
+                    # Verify against API choices if api_key + project are available
+                    context = {
+                        "api_key": self.config.get("api_key", existing_config.get("api_key")),
+                        "project": self.config.get("project", existing_config.get("project")),
+                    }
+                    found = None
+                    try:
+                        if context["api_key"] and context["project"]:
+                            choices = self.adapter.get_dynamic_choices("default_ssh_key", context)
+                            # Choices are strings like "id|name|..."; match on id
+                            for c in choices:
+                                if c.split("|")[0] == key_id:
+                                    found = c
+                                    break
+                    except Exception:
+                        found = None
+                    if found:
                         status_display = get_status_display("configured", "Configured")
-                        display_value = "Auto‑generate per instance"
+                        # Prefer readable name
+                        parts = found.split("|")
+                        display_value = parts[1] if len(parts) > 1 else key_id
                         source_display = "detected"
                     else:
-                        # Verify against API choices if api_key + project are available
-                        context = {
-                            "api_key": self.config.get("api_key", existing_config.get("api_key")),
-                            "project": self.config.get("project", existing_config.get("project")),
-                        }
-                        found = None
-                        try:
-                            if context["api_key"] and context["project"]:
-                                choices = self.adapter.get_dynamic_choices("default_ssh_key", context)
-                                # Choices are strings like "id|name|..."; match on id
-                                for c in choices:
-                                    if c.split("|")[0] == key_id:
-                                        found = c
-                                        break
-                        except Exception:
-                            found = None
-                        if found:
-                            status_display = get_status_display("configured", "Configured")
-                            # Prefer readable name
-                            parts = found.split("|")
-                            display_value = parts[1] if len(parts) > 1 else key_id
-                            source_display = "detected"
-                        else:
-                            status_display = get_status_display("invalid", "Unknown")
-                            display_value = key_id
-                            source_display = "detected"
+                        status_display = get_status_display("invalid", "Unknown")
+                        display_value = key_id
+                        source_display = "detected"
 
                 else:
                     # Generic configured handling
@@ -975,15 +974,7 @@ class GenericSetupWizard:
                     if field.mask_display and value:
                         display_value = mask_strict_last4(value)
                     else:
-                        # Friendly display for SSH key auto-generation sentinel (kept for safety)
-                        if (
-                            field.name == "default_ssh_key"
-                            and isinstance(value, str)
-                            and value.strip() == "_auto_"
-                        ):
-                            display_value = "Auto‑generate per instance (recommended)"
-                        else:
-                            display_value = str(value)
+                        display_value = str(value)
                     source_display = "detected"
 
             else:
@@ -1265,12 +1256,13 @@ class GenericSetupWizard:
 
             if field.help_url:
                 # Render the URL with tasteful accent color and keep it clickable
-                # in supported terminals via OSC 8 hyperlinks.
+                # in supported terminals via OSC 8 hyperlinks. Do not wrap an OSC 8
+                # hyperlink in Rich's [link] tag to avoid nested/duplicated links.
                 try:
                     link_text = hyperlink_support.create_link(field.help_url, field.help_url)
                 except Exception:
                     link_text = field.help_url
-                self.console.print(f"[dim]More info: [/dim][link]{link_text}[/link]")
+                self.console.print(f"[dim]More info: [/dim]{link_text}")
 
         # Get field value based on type
         if field.field_type == FieldType.CHOICE:
@@ -1293,6 +1285,55 @@ class GenericSetupWizard:
                         if isinstance(cached_keys, list) and cached_keys:
                             # Normalize to id|name|created|fingerprint strings for display
                             norm = []
+                            # Build a quick local-id index from metadata.json
+                            local_ids: set[str] = set()
+                            try:
+                                from pathlib import Path as _Path
+                                import json as _json
+                                meta_path = _Path.home() / ".flow" / "keys" / "metadata.json"
+                                if meta_path.exists():
+                                    data = _json.loads(meta_path.read_text())
+                                    if isinstance(data, dict):
+                                        for _kid, _info in data.items():
+                                            p = _Path((_info or {}).get("private_key_path", ""))
+                                            if p.exists():
+                                                local_ids.add(_kid)
+                            except Exception:
+                                local_ids = set()
+
+                            # Fallback helper using SSHKeyManager
+                            def _has_local_copy(fid: str) -> bool:
+                                if not fid:
+                                    return False
+                                if fid in local_ids:
+                                    return True
+                                try:
+                                    from flow._internal.io.http import HttpClient as _Http
+                                    api_key = (self.adapter._current_context.get("api_key")  # type: ignore[attr-defined]
+                                               if hasattr(self.adapter, "_current_context") else None)
+                                    project = (self.adapter._current_context.get("project")  # type: ignore[attr-defined]
+                                               if hasattr(self.adapter, "_current_context") else None)
+                                    if not api_key or not project:
+                                        return False
+                                    http = _Http(
+                                        base_url=self.adapter.api_url,  # type: ignore[attr-defined]
+                                        headers={"Authorization": f"Bearer {api_key}"},
+                                    )
+                                    # Resolve project id
+                                    projects = http.request("GET", "/v2/projects", timeout_seconds=5.0)
+                                    proj_id = None
+                                    for _p in (projects or []):
+                                        if _p.get("name") == project:
+                                            proj_id = _p.get("fid")
+                                            break
+                                    if not proj_id:
+                                        return False
+                                    from flow.providers.mithril.resources.ssh import SSHKeyManager as _Mgr
+                                    mgr = _Mgr(http, proj_id)
+                                    return bool(mgr.find_matching_local_key(fid))
+                                except Exception:
+                                    return False
+
                             for k in cached_keys:
                                 try:
                                     fid = k.get("id") or k.get("fid")
@@ -1300,14 +1341,15 @@ class GenericSetupWizard:
                                     created = (k.get("created_at") or "")
                                     fprint = (k.get("fingerprint") or "")
                                     if fid:
+                                        if _has_local_copy(fid):
+                                            name = f"{name} (local copy)"
                                         norm.append(f"{fid}|{name}|{created}|{fprint}")
                                 except Exception:
                                     continue
                             if norm:
                                 choice_strings = [
-                                    "_auto_|Platform auto-generates per instance (recommended)",
-                                    "GENERATE_SERVER|Generate new SSH key on Mithril platform",
-                                    "GENERATE_LOCAL|Generate new SSH key locally with ssh-keygen",
+                                    "GENERATE_SERVER|Generate on Mithril (recommended; saves key locally)",
+                                    "GENERATE_LOCAL|Generate locally (uploads public key)",
                                 ] + norm
                 except Exception:
                     choice_strings = None
@@ -1427,7 +1469,13 @@ class GenericSetupWizard:
                         "Tip: Upload from this machine:\n  flow ssh-keys upload ~/.ssh/id_ed25519.pub"
                     )
                     from flow.links import WebLinks
-                    header_parts.append(f"Manage keys: {WebLinks.ssh_keys()}")
+                    header_parts.append(
+                        "Notes:\n"
+                        "- '(local copy)' means a matching local private key is present.\n"
+                        "- Generate on Mithril (recommended) saves the private key to ~/.flow/keys.\n"
+                        "- Generate locally uploads only the public key.\n"
+                        f"Manage keys: {WebLinks.ssh_keys()}"
+                    )
 
                 selected = select_from_options(
                     console=self.console,
@@ -1563,6 +1611,13 @@ class GenericSetupWizard:
                     _pf(["flow", "init"])  # warm projects/keys using fresh auth
                 elif field_name == "project" and isinstance(self.config.get(field_name), str):
                     os.environ["MITHRIL_PROJECT"] = str(self.config[field_name])
+                    # Reset prefetch context to avoid cross-project cache leaks in long-lived sessions
+                    try:
+                        from flow.cli.utils.prefetch import reset_context as _reset_ctx
+
+                        _reset_ctx()
+                    except Exception:
+                        pass
                     from flow.cli.utils.prefetch import prefetch_for_command as _pf
                     _pf(["flow", "init"])  # warm ssh keys for selected project
                 elif field_name == "region" and isinstance(self.config.get(field_name), str):
@@ -1672,7 +1727,8 @@ class GenericSetupWizard:
         bullet = f"[{colors['primary']}]•[/{colors['primary']}]"
 
         body_lines = [
-            f"{bullet} [bold]Demo mode:[/bold] [accent]mock[/accent] — [dim]no real provisioning[/dim]",
+            f"{bullet} [bold]Sandbox only — no real resources are created.[/bold]",
+            f"{bullet} Provider: [accent]mock[/accent]",
             f"{bullet} Switch to real: [accent]flow init --provider mithril[/accent] or [accent]flow demo stop[/accent]",
             f"{bullet} SSH access: Your [bold]Default SSH Key[/bold] lets you securely log in",
             f"{bullet} Manage keys: [link]{WebLinks.ssh_keys()}[/link]",
@@ -1680,9 +1736,9 @@ class GenericSetupWizard:
 
         return Panel(
             "\n".join(body_lines),
-            title=f"{format_text('subtitle', 'Demo mode active')}",
+            title=f"{format_text('subtitle', 'DEMO MODE')}",
             title_align=panel_styles["info"]["title_align"],
-            border_style=panel_styles["info"]["border_style"],
+            border_style=theme_manager.get_color("warning"),
             padding=panel_styles["info"]["padding"],
             width=SPACING["panel_width"],
         )
