@@ -67,12 +67,20 @@ class IRemoteOperations(Protocol):
         """
         ...
 
-    def open_shell(self, task_id: str, command: str | None = None) -> None:
+    def open_shell(
+        self,
+        task_id: str,
+        command: str | None = None,
+        node: int | None = None,
+        progress_context: object | None = None,
+    ) -> None:
         """Open interactive shell or execute command with TTY.
 
         Args:
             task_id: Task identifier
-            command: Optional command to execute
+            command: Optional command to execute on the remote host
+            node: Optional node index for multi-instance tasks
+            progress_context: Optional progress adapter/context provided by caller
 
         Raises:
             TaskNotFoundError: Task doesn't exist
