@@ -83,14 +83,36 @@ class InstanceMatcher:
         """Find instances matching GPU requirements."""
         candidates = []
 
-        # Exact match preferred
-        for instance in self._by_gpu_type.get(gpu_type.lower(), []):
+        # Exact match preferred. Accept multiple naming conventions for gpu_type.
+        norm = gpu_type.lower()
+        aliases = {norm}
+        # Normalize common variants: a100 vs a100-80gb
+        if "a100" in norm and "80" not in norm:
+            aliases.add("a100-80gb")
+        if "h100" in norm and "80" not in norm:
+            aliases.add("h100-80gb")
+
+        # Aggregate candidates across aliases
+        alias_bucket: list[dict[str, Any]] = []
+        for key in aliases:
+            alias_bucket.extend(self._by_gpu_type.get(key, []))
+
+        # Remove duplicates (by instance_type) while preserving order
+        seen_it: set[str] = set()
+        unique_alias_bucket: list[dict[str, Any]] = []
+        for inst in alias_bucket:
+            it = inst.get("instance_type")
+            if it and it not in seen_it:
+                seen_it.add(it)
+                unique_alias_bucket.append(inst)
+
+        for instance in unique_alias_bucket:
             if instance.get("gpu_count") == count and instance.get("available", False):
                 candidates.append(instance)
 
         # If no exact match, find larger instances
         if not candidates:
-            for instance in self._by_gpu_type.get(gpu_type.lower(), []):
+            for instance in unique_alias_bucket:
                 if instance.get("gpu_count") >= count and instance.get("available", False):
                     candidates.append(instance)
 
@@ -100,9 +122,20 @@ class InstanceMatcher:
         """Raise error with helpful suggestions."""
         # Just tell them what's actually available
         available = []
-        for instance in self._by_gpu_type.get(gpu_type.lower(), []):
-            if instance.get("available", False):
-                available.append(f"{instance['instance_type']} ({instance['gpu_count']} GPUs)")
+        norm = gpu_type.lower()
+        keys = {norm}
+        if "a100" in norm and "80" not in norm:
+            keys.add("a100-80gb")
+        if "h100" in norm and "80" not in norm:
+            keys.add("h100-80gb")
+        dedup: dict[str, dict[str, Any]] = {}
+        for key in keys:
+            for instance in self._by_gpu_type.get(key, []):
+                it = instance.get("instance_type")
+                if instance.get("available", False) and it and it not in dedup:
+                    dedup[it] = instance
+        for inst in dedup.values():
+            available.append(f"{inst['instance_type']} ({inst['gpu_count']} GPUs)")
 
         suggestions = []
         if available:
