@@ -156,7 +156,7 @@ def register_providers():
                         required=False,
                         display_name="Default SSH Key",
                         help_text=(
-                            "Choose how SSH should behave in demos. Auto‑generate produces a fresh key per instance."
+                            "Choose how SSH should behave in demos. Generate on Mithril (recommended) saves the private key locally; or pick a local public key."
                         ),
                         dynamic_choices=True,
                     ),
@@ -194,7 +194,7 @@ def register_providers():
                 if field_name == "default_ssh_key":
                     # Include local ~/.ssh/*.pub keys as selectable options in demo
                     choices = [
-                        "_auto_|Auto‑generate per instance (recommended)",
+                        "GENERATE_SERVER|Generate on Mithril (recommended; saves key locally)",
                         "none|No SSH access",
                     ]
                     try:
@@ -222,13 +222,10 @@ def register_providers():
                         is_valid=ok, display_value=value, message=None if ok else "Unknown region"
                     )
                 if field_name == "default_ssh_key":
-                    # Accept auto, none, or a local public key path prefixed with local:
-                    if value in {"_auto_", "none"}:
-                        display = (
-                            "Auto‑generate per instance" if value == "_auto_" else "No SSH access"
-                        )
+                    # Accept 'none' or a local public key path prefixed with local:
+                    if value == "none":
                         return ValidationResult(
-                            is_valid=True, display_value=display, processed_value=value
+                            is_valid=True, display_value="No SSH access", processed_value=value
                         )
                     if value.startswith("local:"):
                         key_path = value.split(":", 1)[1]
