@@ -18,10 +18,19 @@ The provider will then be automatically available through the factory.
 """
 
 # Import providers to trigger registration
-from . import mithril
-from .base import PricingModel, ProviderCapabilities, ProviderInfo
-from .factory import create_provider
-from .registry import ProviderRegistry
+from flow.providers import mithril  # noqa: F401
+
+try:  # optional providers
+    from flow.providers import local  # noqa: F401
+except Exception:
+    pass
+try:
+    from flow.providers import mock  # noqa: F401
+except Exception:
+    pass
+from flow.providers.base import PricingModel, ProviderCapabilities, ProviderInfo
+from flow.providers.factory import create_provider
+from flow.providers.registry import ProviderRegistry
 
 __all__ = [
     "create_provider",
