@@ -6,9 +6,9 @@ This package provides adapters between Mithril and Flow domains:
 - Mount specification adaptation
 """
 
-from .models import MithrilAdapter
-from .mounts import MithrilMountAdapter
-from .storage import MithrilStorageMapper
+from flow.providers.mithril.adapters.models import MithrilAdapter
+from flow.providers.mithril.adapters.mounts import MithrilMountAdapter
+from flow.providers.mithril.adapters.storage import MithrilStorageMapper
 
 __all__ = [
     # Models adapter
