@@ -5,6 +5,7 @@ SSH availability checks with file transfers for a seamless experience.
 """
 
 import logging
+import time
 from contextlib import contextmanager
 from dataclasses import dataclass
 from pathlib import Path
@@ -13,19 +14,23 @@ from typing import TYPE_CHECKING, Optional
 from flow.api.models import Task
 from flow.cli.utils.animated_progress import AnimatedEllipsisProgress
 from flow.errors import FlowError
-
-from .ssh_waiter import ExponentialBackoffSSHWaiter, ISSHWaiter, SSHConnectionInfo
-from .transfer_strategies import (
+from flow.providers.mithril.core.constants import EXPECTED_PROVISION_MINUTES
+from flow.providers.mithril.ssh_waiter import (
+    ExponentialBackoffSSHWaiter,
+    ISSHWaiter,
+    SSHConnectionInfo,
+)
+from flow.providers.mithril.transfer_strategies import (
     ITransferStrategy,
     RsyncTransferStrategy,
     TransferError,
     TransferResult,
 )
-from .core.constants import EXPECTED_PROVISION_MINUTES
 
 if TYPE_CHECKING:
     from rich.console import Console
-    from .provider import MithrilProvider
+
+    from flow.providers.mithril.provider import MithrilProvider
 
 logger = logging.getLogger(__name__)
 
@@ -74,28 +79,62 @@ class IProgressReporter:
 class RichProgressReporter(IProgressReporter):
     """Progress reporter using Rich console."""
 
-    def __init__(self, console: "Console"):
+    def __init__(self, console: "Console" = None):
         """Initialize with Rich console."""
-        self.console = console
+        if console is None:
+            # Lazy import to avoid heavy Console in non-CLI contexts
+            from rich.console import Console as _Console
+
+            self.console = _Console()
+        else:
+            self.console = console
         self._current_progress = None
 
     @contextmanager
     def ssh_wait_progress(self, message: str):
         """Show animated progress for SSH wait."""
-        with AnimatedEllipsisProgress(self.console, message) as progress:
-            self._current_progress = progress
+        min_display_seconds = 2.0
+        progress = AnimatedEllipsisProgress(
+            self.console,
+            f"[dim]{message}[/dim]",
+            transient=True,
+            start_immediately=True,
+        )
+        start_ts = time.monotonic()
+        progress.__enter__()
+        self._current_progress = progress
+        try:
             yield progress
+        finally:
             self._current_progress = None
+            elapsed = time.monotonic() - start_ts
+            if elapsed < min_display_seconds:
+                time.sleep(min_display_seconds - elapsed)
+            progress.__exit__(None, None, None)
 
     @contextmanager
     def transfer_progress(self, message: str):
         """Show progress for file transfer."""
-        # For now, use same animated progress
-        # TODO: Could enhance with Rich progress bar showing bytes/speed
-        with AnimatedEllipsisProgress(self.console, message, transient=True) as progress:
-            self._current_progress = progress
+        # For now, use same animated progress with immediate start and min display time.
+        # Ensure message uses Rich markup and remains concise to avoid raw tags showing.
+        min_display_seconds = 2.0
+        progress = AnimatedEllipsisProgress(
+            self.console,
+            f"[dim]{message}[/dim]",
+            transient=True,
+            start_immediately=True,
+        )
+        start_ts = time.monotonic()
+        progress.__enter__()
+        self._current_progress = progress
+        try:
             yield progress
+        finally:
             self._current_progress = None
+            elapsed = time.monotonic() - start_ts
+            if elapsed < min_display_seconds:
+                time.sleep(min_display_seconds - elapsed)
+            progress.__exit__(None, None, None)
 
     def update_status(self, message: str) -> None:
         """Update status with Rich formatting."""
@@ -117,9 +156,9 @@ class CodeTransferManager:
     def __init__(
         self,
         provider: Optional["MithrilProvider"] = None,
-        ssh_waiter: Optional[ISSHWaiter] = None,
-        transfer_strategy: Optional[ITransferStrategy] = None,
-        progress_reporter: Optional[IProgressReporter] = None,
+        ssh_waiter: ISSHWaiter | None = None,
+        transfer_strategy: ITransferStrategy | None = None,
+        progress_reporter: IProgressReporter | None = None,
     ):
         """Initialize code transfer manager.
 
@@ -135,7 +174,7 @@ class CodeTransferManager:
         self.progress_reporter = progress_reporter
 
     def transfer_code_to_task(
-        self, task: Task, config: Optional[CodeTransferConfig] = None
+        self, task: Task, config: CodeTransferConfig | None = None
     ) -> TransferResult:
         """Transfer code to a running task.
 
@@ -221,17 +260,25 @@ class CodeTransferManager:
             # This just builds the connection info without actually testing SSH
             try:
                 # Use a very short timeout for existing connections
-                # The wait_for_ssh will just build the connection info quickly
-                connection = self.ssh_waiter.wait_for_ssh(
-                    task,
-                    timeout=3,
-                    progress_callback=None,  # 3 second quick check
-                )
+                # Show a brief status so the CLI doesn't appear to hang
+                # Always show a short-lived status to avoid apparent hangs,
+                # falling back to a lightweight reporter if none provided.
+                reporter = self.progress_reporter or RichProgressReporter(console=None)  # type: ignore[arg-type]
+                with reporter.ssh_wait_progress("Checking VM connectivity and code sync"):
+                    connection = self.ssh_waiter.wait_for_ssh(
+                        task,
+                        timeout=3,
+                        progress_callback=None,  # 3 second quick check
+                    )
                 logger.info("SSH connection ready")
                 return connection
             except Exception as e:
-                # If quick check fails, fall back to normal wait behavior
-                logger.warning(f"SSH quick check failed, retrying: {e}")
+                # If quick check fails, fall back to normal wait behavior.
+                # Avoid noisy suggestion blocks from FlowError.__str__ in pre-retry logs.
+                base_message = e.message if isinstance(e, FlowError) else str(e).split("\n", 1)[0]
+                logger.info(
+                    f"SSH quick check did not pass; continuing with full wait: {base_message}"
+                )
 
         # SSH not yet available - show waiting progress
         logger.info(f"Waiting for task {task.task_id} to be ready for SSH access")
@@ -288,19 +335,22 @@ class CodeTransferManager:
         # Progress callback for transfer
         def transfer_progress(progress):
             if self.progress_reporter:
-                if progress.current_file:
-                    # Clean up file path display
-                    file_display = progress.current_file
-                    if "/" in file_display:
-                        file_display = file_display.split("/")[-1]  # Just show filename
-                    self.progress_reporter.update_status(f"Uploading: {file_display}")
-                elif progress.percentage:
-                    status = f"Progress: {progress.percentage:.0f}%"
-                    if progress.speed:
-                        status += f" @ {progress.speed}"
-                    if progress.eta:
-                        status += f" (ETA: {progress.eta})"
-                    self.progress_reporter.update_status(status)
+                # If reporter supports richer transfer update, use it; else fallback to status
+                if hasattr(self.progress_reporter, "update_transfer"):
+                    self.progress_reporter.update_transfer(
+                        progress.percentage, progress.speed, progress.eta, progress.current_file
+                    )
+                else:
+                    if progress.current_file:
+                        file_display = progress.current_file.split("/")[-1]
+                        self.progress_reporter.update_status(f"Uploading: {file_display}")
+                    elif progress.percentage:
+                        status = f"Progress: {progress.percentage:.0f}%"
+                        if progress.speed:
+                            status += f" @ {progress.speed}"
+                        if progress.eta:
+                            status += f" (ETA: {progress.eta})"
+                        self.progress_reporter.update_status(status)
 
         try:
             # Ensure target directory exists
@@ -348,7 +398,7 @@ class CodeTransferManager:
             CodeTransferError: If verification fails
         """
         # Simple verification - check if target directory exists and has files
-        from .remote_operations import MithrilRemoteOperations
+        from flow.providers.mithril.remote_operations import MithrilRemoteOperations
 
         remote_ops = MithrilRemoteOperations(self.provider)
 
@@ -377,7 +427,7 @@ class CodeTransferManager:
             connection: SSH connection information
             target_dir: Target directory path
         """
-        from .remote_operations import MithrilRemoteOperations
+        from flow.providers.mithril.remote_operations import MithrilRemoteOperations
 
         remote_ops = MithrilRemoteOperations(self.provider)
 
