@@ -10,6 +10,8 @@ from __future__ import annotations
 
 from datetime import datetime, timezone
 from typing import Any
+import os
+import logging
 
 from flow._internal.io.http_interfaces import IHttpClient
 from flow.api.models import Task, TaskConfig, TaskStatus
@@ -36,6 +38,7 @@ class TaskService:
         default_region: str = DEFAULT_REGION,
         default_ssh_user: str = DEFAULT_SSH_USER,
         default_ssh_port: int = DEFAULT_SSH_PORT,
+        ssh_resolver: object | None = None,
     ) -> None:
         self._http = http
         self._pricing = pricing
@@ -43,6 +46,8 @@ class TaskService:
         self._default_region = default_region
         self._default_ssh_user = default_ssh_user
         self._default_ssh_port = default_ssh_port
+        # Optional centralized SSH resolver (provider-level)
+        self._ssh_resolver = ssh_resolver
 
     def build_task(
         self,
@@ -52,6 +57,7 @@ class TaskService:
         fetch_instance_details: bool = False,
     ) -> Task:
         task_id = bid_data.get("fid", "")
+        debug = os.environ.get("FLOW_SSH_DEBUG") == "1"
 
         # Name resolution
         bid_name = bid_data.get("name", "")
@@ -62,7 +68,21 @@ class TaskService:
         else:
             name = f"task-{task_id[:8]}" if len(task_id) > 8 else f"task-{task_id}"
 
-        status = self._map_mithril_status_to_enum(bid_data.get("status", "pending"))
+        # Map Mithril bid status to TaskStatus; accept common variants
+        # Mithril may return bid.status in various forms, e.g. "Allocated", "Terminated",
+        # or instance-like constants such as "STATUS_TERMINATED". Normalize aggressively.
+        raw_status = str(bid_data.get("status", "pending")).strip().lower()
+        # Normalize known prefixes (handle API variants like STATUS_TERMINATED)
+        if raw_status.startswith("status_"):
+            raw_status = raw_status.replace("status_", "")
+        # Some APIs return past-tense; normalize to our canonical set
+        if raw_status == "terminating":
+            raw_status = "preempting"
+        if raw_status == "terminated":
+            raw_status = "cancelled"
+        status = self._map_mithril_status_to_enum(raw_status)
+        if debug:
+            print(f"[build_task] bid={task_id} status_raw={bid_data.get('status')} normalized={raw_status} mapped={status.value}")
 
         # Timestamps
         # created_at may be datetime or ISO string; handle both
@@ -140,44 +160,146 @@ class TaskService:
         instances = bid_data.get("instances", [])
         instance_created_at = None
 
-        if instances and isinstance(instances, list) and instances[0]:
-            first = instances[0]
-            if isinstance(first, str):
+        # Prefer centralized resolver when available to avoid stale endpoints.
+        if self._ssh_resolver and fetch_instance_details:
+            try:
+                debug = os.environ.get("FLOW_SSH_DEBUG") == "1"
+                host, port = self._ssh_resolver.resolve(task_id, tcp_probe=False, debug=debug)  # type: ignore[attr-defined]
+                if host:
+                    ssh_host = host
+                    try:
+                        ssh_port = int(port or self._default_ssh_port)
+                    except Exception:
+                        ssh_port = self._default_ssh_port
+            except Exception:
+                # Fall back to legacy logic below
+                pass
+
+        if not ssh_host and instances and isinstance(instances, list):
+            chosen: dict | str | None = None
+
+            # Prefer dict instances; otherwise resolve strings (optionally with details)
+            dict_instances = [inst for inst in instances if isinstance(inst, dict)]
+            if dict_instances:
+                # Choose most recent non-terminated/cancelled, else last
+                for inst in reversed(dict_instances):
+                    inst_status = str(inst.get("status", "")).lower()
+                    if debug:
+                        print(f"[build_task] bid={task_id} dict-inst status={inst_status} ssh_dest={inst.get('ssh_destination')} public_ip={inst.get('public_ip')}")
+                    if not any(s in inst_status for s in ("termin", "cancel")):
+                        chosen = inst
+                        break
+                if chosen is None:
+                    chosen = dict_instances[-1]
+            else:
+                # Instances are IDs; if allowed, fetch details and pick a live one
                 if fetch_instance_details:
-                    inst_data = self._fetch_instance_details(first)
-                    if inst_data:
-                        instances[0] = inst_data
-                        ssh_destination = inst_data.get("ssh_destination")
-                        if ssh_destination:
-                            ssh_host, ssh_port = self._parse_ssh_destination(ssh_destination)
-                        if inst_data.get("created_at"):
-                            try:
-                                instance_created_at = datetime.fromisoformat(
-                                    inst_data["created_at"].replace("Z", "+00:00")
-                                )
-                            except Exception:
-                                instance_created_at = None
-            elif isinstance(first, dict):
-                ssh_destination = first.get("ssh_destination")
+                    for inst_id in reversed(instances):
+                        if not isinstance(inst_id, str):
+                            continue
+                        inst_data = self._fetch_instance_details(inst_id)
+                        if not inst_data:
+                            continue
+                        inst_status = str(inst_data.get("status", "")).lower()
+                        if debug:
+                            print(f"[build_task] bid={task_id} fetched inst={inst_id} status={inst_status} ssh_dest={inst_data.get('ssh_destination')} public_ip={inst_data.get('public_ip')}")
+                        # Take the first non-terminated; keep updating so we fall back to the latest
+                        chosen = inst_data
+                        if not any(s in inst_status for s in ("termin", "cancel")):
+                            break
+                else:
+                    # No details requested; assume the latest id is most recent
+                    chosen = instances[-1]
+
+            # Populate SSH info from the chosen instance
+            if isinstance(chosen, dict):
+                ssh_destination = chosen.get("ssh_destination")
                 if ssh_destination:
                     ssh_host, ssh_port = self._parse_ssh_destination(ssh_destination)
                 else:
-                    public_ip = first.get("public_ip")
+                    public_ip = chosen.get("public_ip")
                     if public_ip:
                         ssh_host = public_ip
                         ssh_port = self._default_ssh_port
-
-                if first.get("created_at"):
+                if chosen.get("created_at"):
                     try:
                         instance_created_at = datetime.fromisoformat(
-                            first["created_at"].replace("Z", "+00:00")
+                            str(chosen["created_at"]).replace("Z", "+00:00")
                         )
                     except Exception:
                         instance_created_at = None
+            # If chosen is a plain string, we could not enrich; leave ssh_host None
 
             if ssh_host:
                 ssh_command = f"ssh -p {ssh_port} {self._default_ssh_user}@{ssh_host}"
 
+        # If still no ssh_host (instances list stale), try enriching from the instance ids we have
+        if not ssh_host and fetch_instance_details and isinstance(instances, list):
+            try:
+                for inst_id in reversed(instances):
+                    if not isinstance(inst_id, str):
+                        continue
+                    doc = self._fetch_instance_details(inst_id)
+                    if not doc:
+                        continue
+                    st = str(doc.get("status", "")).lower()
+                    ssh_destination = doc.get("ssh_destination")
+                    public_ip = doc.get("public_ip")
+                    host: str | None = None
+                    port: int = self._default_ssh_port
+                    if ssh_destination:
+                        host, port = self._parse_ssh_destination(ssh_destination)
+                    elif public_ip:
+                        host = public_ip
+                    if debug:
+                        print(f"[build_task] fallback inst={inst_id} status={st} host={host} port={port}")
+                    if host:
+                        ssh_host, ssh_port = host, port
+                        if doc.get("created_at"):
+                            try:
+                                instance_created_at = datetime.fromisoformat(
+                                    str(doc["created_at"]).replace("Z", "+00:00")
+                                )
+                            except Exception:
+                                instance_created_at = None
+                        # Prefer non-terminated; if this one is terminated, keep going to find a live one
+                        if not any(s in st for s in ("termin", "cancel")):
+                            break
+            except Exception:
+                pass
+
+        # Final resort: project-scan by bid to find a live instance (spec: /v2/instances?project=)
+        if not ssh_host and fetch_instance_details:
+            try:
+                all_docs = self._instances.list_project_instances_by_bid(task_id, max_pages=3)
+                for doc in reversed(all_docs):  # latest first
+                    st = str(doc.get("status", "")).lower()
+                    if any(s in st for s in ("termin", "cancel")):
+                        continue
+                    ssh_destination = doc.get("ssh_destination")
+                    public_ip = doc.get("public_ip")
+                    host: str | None = None
+                    port: int = self._default_ssh_port
+                    if ssh_destination:
+                        host, port = self._parse_ssh_destination(ssh_destination)
+                    elif public_ip:
+                        host = public_ip
+                    if host:
+                        ssh_host, ssh_port = host, port
+                        if doc.get("created_at"):
+                            try:
+                                instance_created_at = datetime.fromisoformat(
+                                    str(doc["created_at"]).replace("Z", "+00:00")
+                                )
+                            except Exception:
+                                instance_created_at = None
+                        break
+            except Exception:
+                pass
+
+        if debug:
+            print(f"[build_task] bid={task_id} final ssh_host={ssh_host} ssh_port={ssh_port}")
+
         # Provider metadata
         provider_metadata: dict[str, Any] = {
             "provider": "mithril",
