@@ -42,8 +42,9 @@ class ProjectResolver:
             http_client: HTTP client for API requests
         """
         self.http = http_client
-        self._cache: dict[str, str] = {}  # name -> ID mapping
-        self._projects_cache: list[Project] | None = None
+        self._cache: dict[str, tuple[str, float]] = {}  # name -> (ID, ts)
+        self._projects_cache: tuple[list[Project], float] | None = None
+        self._ttl_seconds: float = 300.0  # 5 minutes
 
     def resolve(self, project_identifier: str) -> str:
         """Resolve project name or ID to project ID.
@@ -65,15 +66,31 @@ class ProjectResolver:
             logger.debug(f"Project identifier is already a UUID: {project_identifier}")
             return project_identifier
 
-        # Check cache first
-        if project_identifier in self._cache:
-            logger.debug(f"Resolved project '{project_identifier}' from cache")
-            return self._cache[project_identifier]
+        # Check cache first (TTL)
+        try:
+            item = self._cache.get(project_identifier)
+            if item is not None:
+                pid, ts = item
+                import time as _t
+
+                if _t.time() - ts < self._ttl_seconds:
+                    logger.debug(f"Resolved project '{project_identifier}' from cache")
+                    return pid
+                else:
+                    self._cache.pop(project_identifier, None)
+        except Exception:
+            pass
 
         # Fetch and resolve
         project_id = self._resolve_from_api(project_identifier)
         if project_id:
-            self._cache[project_identifier] = project_id
+            # Cache with TTL timestamp
+            try:
+                import time as _t
+
+                self._cache[project_identifier] = (project_id, _t.time())
+            except Exception:
+                pass
             logger.info(f"Resolved project '{project_identifier}' to ID: {project_id}")
             return project_id
 
@@ -129,7 +146,14 @@ class ProjectResolver:
             List of Project objects
         """
         if self._projects_cache is not None:
-            return self._projects_cache
+            try:
+                projects, ts = self._projects_cache
+                import time as _t
+
+                if _t.time() - ts < self._ttl_seconds:
+                    return projects
+            except Exception:
+                pass
 
         try:
             response = self.http.request(
@@ -140,7 +164,7 @@ class ProjectResolver:
             # API returns list directly
             projects_data = response if isinstance(response, list) else []
 
-            self._projects_cache = [
+            projects_list = [
                 Project(
                     fid=p["fid"],
                     name=p["name"],
@@ -150,8 +174,14 @@ class ProjectResolver:
                 if "fid" in p and "name" in p and "created_at" in p
             ]
 
-            logger.debug(f"Loaded {len(self._projects_cache)} projects from API")
-            return self._projects_cache
+            logger.debug(f"Loaded {len(projects_list)} projects from API")
+            try:
+                import time as _t
+
+                self._projects_cache = (projects_list, _t.time())
+            except Exception:
+                self._projects_cache = (projects_list, 0.0)
+            return projects_list
 
         except Exception as e:
             logger.error(f"Failed to fetch projects: {e}")
