@@ -1,11 +1,10 @@
-"""Quota-aware instance selection for Mithril provider.
+"""Quota-aware instance selection for the Mithril provider.
 
-Simple, correct quota management following the principle:
-"Fail fast with clear errors, suggest alternatives."
+Implements basic quota checks that fail fast with clear errors and offer
+suggested alternatives.
 """
 
 from dataclasses import dataclass
-from typing import Optional
 
 
 @dataclass
@@ -35,10 +34,11 @@ class QuotaChecker:
     @staticmethod
     def check_quota_url() -> str:
         """Return the quota check URL."""
-        return "https://app.mithril.ai/instances/quotas"
+        from flow.links import WebLinks
+        return WebLinks.quotas_instances()
 
     @staticmethod
-    def format_quota_error(requested: str, suggestion: Optional[str] = None) -> str:
+    def format_quota_error(requested: str, suggestion: str | None = None) -> str:
         """Format a clear quota error message."""
         msg = f"No quota available for {requested}"
         if suggestion:
