@@ -1,7 +1,7 @@
 """Data models for script size handling."""
 
 from dataclasses import dataclass, field
-from typing import Any, Dict, Optional
+from typing import Any
 
 
 @dataclass
@@ -15,7 +15,7 @@ class PreparedScript:
     content: str
     strategy: str
     requires_network: bool = False
-    metadata: Dict[str, Any] = field(default_factory=dict)
+    metadata: dict[str, Any] = field(default_factory=dict)
 
     @property
     def size_bytes(self) -> int:
@@ -23,12 +23,12 @@ class PreparedScript:
         return len(self.content.encode("utf-8"))
 
     @property
-    def original_size(self) -> Optional[int]:
+    def original_size(self) -> int | None:
         """Get the original script size if stored in metadata."""
         return self.metadata.get("original_size")
 
     @property
-    def compression_ratio(self) -> Optional[float]:
+    def compression_ratio(self) -> float | None:
         """Get compression ratio if script was compressed."""
         if self.strategy == "compressed" and self.original_size:
             return self.original_size / self.size_bytes
