@@ -206,13 +206,11 @@ class StartupScriptBuilder:
         logger.debug("--- End Script Content ---")
         logger.debug("=" * 80)
 
-        # Compress if needed
-        compressed = False
+        # Always compress to unify the runtime path and reduce edge cases
         original_size = len(full_content.encode("utf-8"))
-        if self.compressor.should_compress(full_content, self.max_uncompressed_size):
-            full_content = self.compressor.compress(full_content)
-            compressed = True
-            logger.debug(f"Script compressed. New size: {len(full_content.encode('utf-8'))} bytes")
+        full_content = self.compressor.compress(full_content)
+        compressed = True
+        logger.debug(f"Script compressed. New size: {len(full_content.encode('utf-8'))} bytes")
 
         return StartupScript(
             content=full_content,
