@@ -16,7 +16,13 @@ class DevVMDockerSection(ScriptSection):
         return 38
 
     def should_include(self, context: ScriptContext) -> bool:
-        return context.environment.get("FLOW_DEV_VM") == "true"
+        env = getattr(context, "environment", None)
+        if not isinstance(env, dict):
+            env = getattr(context, "env_vars", {}) if isinstance(getattr(context, "env_vars", None), dict) else {}
+        # Accept either explicit environment switch or a test-only is_dev_vm flag
+        is_dev_vm_flag = bool(getattr(context, "is_dev_vm", False))
+        has_image = bool(getattr(context, "docker_image", None))
+        return has_image and (env.get("FLOW_DEV_VM") == "true" or is_dev_vm_flag)
 
     def generate(self, context: ScriptContext) -> str:
         return textwrap.dedent(
