@@ -116,7 +116,7 @@ def ensure_docker_available() -> str:
             # Prefer distro packages; fall back to get.docker.com
             if command -v apt-get >/dev/null 2>&1; then
                 apt-get update -qq || true
-                apt-get install -y -qq docker.io || true
+                apt-get install -y docker.io || true
             elif command -v dnf >/dev/null 2>&1; then
                 dnf -y install docker || true
             elif command -v yum >/dev/null 2>&1; then
@@ -283,3 +283,33 @@ def ensure_basic_tools() -> str:
         fi
         """
     ).strip()
+
+
+def ensure_install_pkgs_function() -> str:
+    """Return only the cross-distro install_pkgs shell function.
+
+    This light-weight helper keeps the header small while enabling later
+    sections to call install_pkgs when needed.
+    """
+    return textwrap.dedent(
+        """
+        install_pkgs() {
+            if command -v apt-get >/dev/null 2>&1; then
+                apt-get update -qq && apt-get install -y -qq "$@"
+            elif command -v dnf >/dev/null 2>&1; then
+                dnf -y install "$@"
+            elif command -v yum >/dev/null 2>&1; then
+                yum -y install "$@"
+            elif command -v apk >/dev/null 2>&1; then
+                apk add --no-cache "$@"
+            elif command -v zypper >/dev/null 2>&1; then
+                zypper -n install "$@"
+            elif command -v pacman >/dev/null 2>&1; then
+                pacman -Sy --noconfirm "$@"
+            else
+                echo "WARNING: No supported package manager found to install: $*"
+                return 1
+            fi
+        }
+        """
+    ).strip()
