@@ -1,6 +1,11 @@
-"""Mithril provider setup implementation.
+"""Deprecated Mithril provider setup implementation.
 
-Handles Mithril-specific configuration including API keys, projects, SSH keys, and regions.
+This module is retained for backward compatibility only and will be removed
+in a future release. The canonical setup path uses
+`flow.providers.mithril.setup.adapter.MithrilSetupAdapter` in conjunction with
+`ConfigManager`.
+
+Do not import this module from new code.
 """
 
 import configparser
@@ -17,7 +22,7 @@ from flow.providers.mithril.core.constants import VALID_REGIONS
 
 
 class MithrilProviderSetup(ProviderSetup):
-    """Mithril-specific setup implementation."""
+    """Deprecated: use `MithrilSetupAdapter` instead."""
 
     def __init__(self, console: Console | None = None):
         """Initialize Mithril setup.
@@ -69,8 +74,7 @@ class MithrilProviderSetup(ProviderSetup):
         if region:
             config["region"] = region
 
-        # Save API key to credentials file (Mithril-specific)
-        self._save_credentials(api_key)
+        # Deprecated path wrote to credentials file; no-op now
 
         return SetupResult(success=True, config=config)
 
@@ -105,8 +109,7 @@ class MithrilProviderSetup(ProviderSetup):
 
         # Validate credentials
         if config.get("api_key") and self.validate_credentials(config):
-            # Save API key to credentials file
-            self._save_credentials(config["api_key"])
+            # Deprecated path wrote to credentials file; no-op now
             return SetupResult(success=True, config=config)
         else:
             return SetupResult(success=False, config=config, message="Invalid or missing API key")
@@ -403,31 +406,8 @@ class MithrilProviderSetup(ProviderSetup):
         return None
 
     def _save_credentials(self, api_key: str):
-        """Save API key to credentials file.
+        """Deprecated: previously saved credentials to a local file.
 
-        Args:
-            api_key: The API key to save
+        No longer writes any credentials. Kept to avoid breaking old call sites.
         """
-        credentials_dir = Path.home() / ".flow"
-        credentials_dir.mkdir(exist_ok=True)
-        credentials_path = credentials_dir / "credentials"
-
-        # Read existing credentials
-        config = configparser.ConfigParser()
-        if credentials_path.exists():
-            config.read(credentials_path)
-
-        # Update with new API key
-        if "default" not in config:
-            config.add_section("default")
-        config["default"]["api_key"] = api_key
-
-        # Write back
-        with open(credentials_path, "w") as f:
-            config.write(f)
-
-        # Set appropriate permissions (Unix-like systems)
-        try:
-            credentials_path.chmod(0o600)
-        except Exception:
-            pass  # Windows doesn't support chmod
+        return None
