@@ -70,8 +70,9 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
                 dynamic_choices=True,
                 help_url=WebLinks.ssh_keys(),
                 help_text=(
-                    "Choose how you'll SSH into instances. Pick an existing key from your "
-                    "Mithril account or select Auto‑generate per instance."
+                    "Pick an existing project key or generate one on Mithril (recommended). "
+                    "Keys marked '(local copy)' have a matching local private key. "
+                    "Private keys are never uploaded."
                 ),
                 display_name="Default SSH Key",
                 depends_on=["api_key", "project"],
@@ -140,8 +141,8 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
             payload.setdefault("provider", "mithril")
             saved = manager.save(payload)
 
-            # Write canonical env script
-            manager.write_env_script(saved)
+            # Write canonical env script (no API key by default)
+            manager.write_env_script(saved, include_api_key=False)
 
             # Set up shell completion automatically
             try:
@@ -250,17 +251,12 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
 
         # Handle platform auto-generation (recommended)
         if ssh_key == "_auto_":
-            self.console.print(
-                "\n[green]✓[/green] Platform will auto-generate SSH keys for each instance"
-            )
-            self.console.print(
-                "[dim]This is the recommended secure option - each instance gets unique keys[/dim]\n"
-            )
-            return ValidationResult(
-                is_valid=True,
-                display_value="Platform auto-generates (secure)",
-                processed_value="_auto_",
-            )
+            generated_key_id = self._generate_server_side_key()
+            if generated_key_id:
+                return ValidationResult(
+                    is_valid=True, display_value=generated_key_id, processed_value=generated_key_id
+                )
+            return ValidationResult(is_valid=False, message="Failed to generate SSH key")
 
         # Handle generation options
         if ssh_key == "GENERATE_SERVER":
@@ -297,7 +293,7 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
         if ssh_key.startswith("sshkey_"):
             display_value = f"Platform key ({ssh_key[:14]}...)"
         elif ssh_key == "_auto_":
-            display_value = "Platform auto-generates (secure)"
+            display_value = "Deprecated (_auto_)"
         else:
             display_value = "Configured"
         return ValidationResult(is_valid=True, display_value=display_value)
@@ -330,12 +326,11 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
         """Get available SSH keys from API plus generation options."""
         choices = []
 
-            # Add generation options first
+        # Add generation options first
         choices.extend(
             [
-                    "_auto_|Platform auto‑generate per instance",
-                "GENERATE_SERVER|Generate new SSH key on Mithril platform",
-                "GENERATE_LOCAL|Generate new SSH key locally with ssh-keygen",
+                "GENERATE_SERVER|Generate on Mithril (recommended; saves key locally)",
+                "GENERATE_LOCAL|Generate locally (uploads public key)",
             ]
         )
 
@@ -347,9 +342,15 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
                 base_url=self.api_url,
                 headers={"Authorization": f"Bearer {api_key}"},
             )
+            # Use MithrilApiClient for typed endpoints
+            try:
+                from flow.providers.mithril.api.client import MithrilApiClient as _Api
 
-            # Get project ID
-            projects = client.request("GET", "/v2/projects", timeout_seconds=10.0)
+                api = _Api(client)
+                projects = api.list_projects()
+            except Exception:
+                # Fallback to direct request on any import/runtime issue
+                projects = client.request("GET", "/v2/projects", timeout_seconds=10.0)
             project_id = None
             for proj in projects:
                 if proj.get("name") == project:
@@ -359,20 +360,79 @@ class MithrilSetupAdapter(ProviderSetupAdapter):
             if not project_id:
                 return choices
 
-            # Get existing SSH keys
-            ssh_keys = client.request("GET", "/v2/ssh-keys", params={"project": project_id}, timeout_seconds=10.0)
+            # Get existing SSH keys via manager (normalized + cached)
+            ssh_manager = None
+            try:
+                from flow.providers.mithril.resources.ssh import SSHKeyManager as _SSHKeyManager
+
+                ssh_manager = _SSHKeyManager(client, project_id)
+                ssh_keys = ssh_manager.list_keys()
+            except Exception:
+                # Fallback to raw API if manager import fails
+                ssh_keys = client.request(
+                    "GET", "/v2/ssh-keys", params={"project": project_id}, timeout_seconds=10.0
+                )
+
+            # Build a set of platform key IDs that have a matching local private key
+            local_ids: set[str] = set()
+            try:
+                from pathlib import Path as _Path
+                import json as _json
+                meta_path = _Path.home() / ".flow" / "keys" / "metadata.json"
+                if meta_path.exists():
+                    data = _json.loads(meta_path.read_text())
+                    if isinstance(data, dict):
+                        for _kid, _info in data.items():
+                            p = _Path((_info or {}).get("private_key_path", ""))
+                            if p.exists():
+                                local_ids.add(_kid)
+            except Exception:
+                pass
+
+            # Iterate keys (supports dicts and SSHKeyModel instances)
             if isinstance(ssh_keys, list):
                 for key in ssh_keys:
-                    # Format: ID|Name|CreatedAt|Fingerprint for richer display
-                    created_at = key.get("created_at", "")
-                    # Extract fingerprint from public key if available
-                    fingerprint = self._extract_fingerprint(key.get("public_key", ""))
-                    required_flag = (
-                        " (required)" if key.get("required") or key.get("is_required") else ""
-                    )
-                    choices.append(
-                        f"{key['fid']}|{key['name']}{required_flag}|{created_at}|{fingerprint}"
-                    )
+                    # Normalize fields for both dict and model cases
+                    if isinstance(key, dict):
+                        created_at = key.get("created_at", "")
+                        public_key = key.get("public_key", "")
+                        required = key.get("required") or key.get("is_required")
+                        fid = key.get("fid")
+                        key_name = key.get("name", "")
+                    else:
+                        # Pydantic model (SSHKeyModel)
+                        created_at = getattr(key, "created_at", "")
+                        public_key = getattr(key, "public_key", "")
+                        required = getattr(key, "required", None) or getattr(key, "is_required", None)
+                        fid = getattr(key, "fid", None)
+                        key_name = getattr(key, "name", "")
+
+                    fingerprint = self._extract_fingerprint(public_key or "")
+                    required_flag = " (required)" if required else ""
+
+                    # Determine if there is a matching local private key
+                    has_local = False
+                    try:
+                        if fid:
+                            if fid in local_ids:
+                                has_local = True
+                            elif ssh_manager is not None:
+                                try:
+                                    if ssh_manager.find_matching_local_key(fid):
+                                        has_local = True
+                                except Exception:
+                                    has_local = False
+                    except Exception:
+                        has_local = False
+
+                    name_display = f"{key_name}{required_flag}"
+                    if has_local:
+                        name_display = f"{name_display} (local copy)"
+
+                    if fid:
+                        choices.append(
+                            f"{fid}|{name_display}|{created_at}|{fingerprint}"
+                        )
 
             return choices
         except Exception:
