@@ -16,6 +16,7 @@ from dataclasses import dataclass
 from typing import TYPE_CHECKING, Optional
 
 from flow.api.models import Task
+from flow.core.ssh_stack import SshStack
 from flow.errors import FlowError
 from flow.utils.circuit_breaker import CircuitBreaker
 
@@ -239,62 +240,26 @@ class SSHTunnelManager:
         remote_host: str,
         ssh_options: list[str] | None = None,
     ) -> list[str]:
-        """Build SSH command for tunnel."""
-        cmd = [
-            "ssh",
-            "-N",  # No command execution
-            "-L",
-            f"{local_port}:{remote_host}:{remote_port}",
-            "-o",
-            "StrictHostKeyChecking=no",
-            "-o",
-            "UserKnownHostsFile=/dev/null",
-            "-o",
-            "PasswordAuthentication=no",
-            "-o",
-            "ConnectTimeout=10",
-            "-o",
-            "ServerAliveInterval=60",
-            "-o",
-            "ServerAliveCountMax=3",
-            "-o",
-            "ExitOnForwardFailure=yes",
-        ]
+        """Build SSH command for tunnel using centralized stack."""
+        forward = ["-N", "-L", f"{local_port}:{remote_host}:{remote_port}"]
 
-        # Add custom SSH options
+        # Prefer explicit env override; otherwise rely on user's agent/defaults
+        key_path = SshStack.find_fallback_private_key()
+
+        cmd = SshStack.build_ssh_command(
+            user=getattr(task, "ssh_user", "ubuntu"),
+            host=getattr(task, "ssh_host"),
+            port=getattr(task, "ssh_port", 22),
+            key_path=key_path,
+            prefix_args=forward,
+        )
+
+        # Add custom options at the end to allow overrides (e.g., -v)
         if ssh_options:
             cmd.extend(ssh_options)
 
-        # Add port if non-standard
-        if task.ssh_port and task.ssh_port != 22:
-            cmd.extend(["-p", str(task.ssh_port)])
-
-        # Add SSH key if configured
-        # Task objects don't have ssh_key_path attribute, check environment
-        ssh_key = os.environ.get("FLOW_SSH_KEY_PATH")
-        if not ssh_key:
-            # Try to get from config file if available
-            from pathlib import Path
-
-            import yaml
-
-            try:
-                config_path = Path.home() / ".flow" / "config.yaml"
-                if config_path.exists():
-                    with open(config_path) as f:
-                        config = yaml.safe_load(f)
-                        ssh_key = config.get("ssh_key_path")
-            except Exception:
-                pass
-
-        if ssh_key:
-            ssh_key = os.path.expanduser(ssh_key)
-            if os.path.exists(ssh_key):
-                cmd.extend(["-i", ssh_key])
-
-        # Add destination
-        cmd.append(f"{task.ssh_user}@{task.ssh_host}")
-
+        # Ensure ExitOnForwardFailure for tunnels
+        cmd.extend(["-o", "ExitOnForwardFailure=yes"])
         return cmd
 
     @staticmethod
