@@ -15,7 +15,8 @@ from typing import TYPE_CHECKING, Optional, Protocol
 from flow.api.models import Task
 from flow.errors import FlowError
 from flow.providers.mithril.core.constants import EXPECTED_PROVISION_MINUTES
-from flow.providers.mithril.ssh_utils import SSHNotReadyError, wait_for_task_ssh_info
+from flow.api.ssh_utils import SSHNotReadyError, wait_for_task_ssh_info
+from flow.core.ssh_stack import SshStack
 
 logger = logging.getLogger(__name__)
 
@@ -119,11 +120,12 @@ class ExponentialBackoffSSHWaiter:
 
         # First, use the shared utility to wait for SSH info
         try:
+            # Use core API wait without UI; this function manages its own progress messaging
             task = wait_for_task_ssh_info(
                 task=task,
                 provider=self.provider,
                 timeout=timeout,
-                progress_callback=progress_callback,
+                show_progress=False,
             )
         except SSHNotReadyError as e:
             # Convert to SSHTimeoutError for compatibility
@@ -158,7 +160,7 @@ class ExponentialBackoffSSHWaiter:
             # The higher-level AnimatedEllipsisProgress handles the display
             if progress_callback:
                 mins, secs = divmod(int(elapsed), 60)
-                status = f"Establishing secure connection ({mins}m {secs}s)"
+                status = f"Waiting for SSH ({mins}m {secs}s elapsed)"
                 progress_callback(status)
 
             # Compute conservative per-attempt timeouts based on remaining time
@@ -167,11 +169,8 @@ class ExponentialBackoffSSHWaiter:
             subprocess_timeout_seconds = min(10, max(3, remaining))
 
             # Test SSH connection
-            if self._test_ssh_connection(
-                connection_info,
-                connect_timeout_seconds=connect_timeout_seconds,
-                subprocess_timeout_seconds=subprocess_timeout_seconds,
-            ):
+            # Use default probe timeouts in the test function to keep compatibility
+            if self._test_ssh_connection(connection_info):
                 logger.info(f"SSH available after {elapsed:.1f} seconds")
                 return connection_info
 
@@ -199,30 +198,26 @@ class ExponentialBackoffSSHWaiter:
         Returns:
             True if SSH is available, False otherwise
         """
-        cmd = [
-            "ssh",
-            "-p",
-            str(connection.port),
-            "-i",
-            str(connection.key_path),
-            "-o",
-            "StrictHostKeyChecking=no",
-            "-o",
-            "UserKnownHostsFile=/dev/null",
-            "-o",
-            f"ConnectTimeout={int(connect_timeout_seconds)}",
-            "-o",
-            "ServerAliveInterval=5",
-            "-o",
-            "ServerAliveCountMax=1",
-            "-o",
-            "PasswordAuthentication=no",
-            "-o",
-            "BatchMode=yes",
-            connection.destination,
-            "echo",
-            "SSH_TEST_OK",
-        ]
+        cmd = SshStack.build_ssh_command(
+            user=connection.user,
+            host=connection.host,
+            port=connection.port,
+            key_path=connection.key_path,
+            remote_command="echo SSH_TEST_OK",
+        )
+        # Override specific timeouts and enforce non-interactive auth for probes
+        cmd.extend(
+            [
+                "-o",
+                f"ConnectTimeout={int(connect_timeout_seconds)}",
+                "-o",
+                "ServerAliveInterval=5",
+                "-o",
+                "ServerAliveCountMax=1",
+                "-o",
+                "BatchMode=yes",
+            ]
+        )
 
         try:
             result = subprocess.run(
@@ -274,6 +269,16 @@ class ExponentialBackoffSSHWaiter:
                 return default_key
             raise FlowError("No SSH key available - provider not set")
 
+        # Ensure provider is ready to resolve project-scoped keys
+        try:
+            if getattr(self.provider, "ssh_key_manager", None) is not None and getattr(
+                self.provider.ssh_key_manager, "project_id", None
+            ) is None:
+                # Best-effort scoping to avoid project validation errors
+                self.provider.ssh_key_manager.project_id = self.provider.project_id
+        except Exception:
+            pass
+
         # Use provider's SSH key resolution
         key_path, error_msg = self.provider.get_task_ssh_connection_info(task.task_id)
         if not key_path:
@@ -298,8 +303,24 @@ class ExponentialBackoffSSHWaiter:
         error_msg = f"SSH connection timeout after {mins}m {secs}s"
 
         # Add instance age information if available
-        instance_age = task.instance_age_seconds
-        instance_mins = int(instance_age / 60) if instance_age else None
+        # Be robust to mocks and tests: instance_age_seconds may be a Mock, callable, string, or None
+        instance_mins = None
+        try:
+            instance_age = getattr(task, "instance_age_seconds", None)
+            # Support callables returning the age
+            if callable(instance_age):
+                instance_age = instance_age()
+            # Coerce to float if possible (handles ints and numeric strings)
+            if instance_age is not None:
+                try:
+                    age_seconds = float(instance_age)
+                    # Cap to 7 days to avoid absurd numbers from bad metadata (consistent with remote_operations)
+                    capped_seconds = max(0.0, min(age_seconds, 7 * 24 * 3600))
+                    instance_mins = int(capped_seconds // 60)
+                except Exception:
+                    instance_mins = None
+        except Exception:
+            instance_mins = None
 
         if instance_mins is not None and instance_mins < 20:
             from flow.providers.mithril.core.constants import EXPECTED_PROVISION_MINUTES
