@@ -1,17 +1,17 @@
-"""Storage backends for Mithril provider.
+"""Storage backends for the Mithril provider.
 
-This module provides storage backend interfaces and implementations for handling
-large startup scripts and other provider-specific storage needs.
+Interfaces and implementations for handling large startup scripts and other
+provider-specific storage needs.
 """
 
-from .backends import (
+from flow.providers.mithril.storage.backends import (
     IStorageBackend,
     LocalHttpBackend,
     StorageConfig,
     StorageError,
     create_storage_backend,
 )
-from .models import StorageMetadata, StorageUrl
+from flow.providers.mithril.storage.models import StorageMetadata, StorageUrl
 
 __all__ = [
     "IStorageBackend",
