@@ -2,7 +2,6 @@
 
 from dataclasses import dataclass
 from datetime import datetime, timezone
-from typing import Optional
 
 
 @dataclass
@@ -10,9 +9,9 @@ class StorageUrl:
     """Represents a URL with metadata for stored content."""
 
     url: str
-    expires_at: Optional[datetime] = None
+    expires_at: datetime | None = None
     content_type: str = "text/x-shellscript"
-    size_bytes: Optional[int] = None
+    size_bytes: int | None = None
 
     @property
     def is_expired(self) -> bool:
@@ -31,5 +30,5 @@ class StorageMetadata:
     content_hash: str
     stored_at: datetime
     content_type: str = "text/x-shellscript"
-    compression: Optional[str] = None
-    original_size_bytes: Optional[int] = None
+    compression: str | None = None
+    original_size_bytes: int | None = None
